@@ -7,7 +7,7 @@
 
 #include "mew.h"
 
-private char version_message[] = "version 4.2 20040809 Yasunari Momoi";
+private char version_message[] = "version 4.2 20050107 Yasunari Momoi";
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -48,17 +48,17 @@ private char version_message[] = "version 4.2 20040809 Yasunari Momoi";
 #endif
 
 enum MBOXTYPE {
-    T_UNKNOWN,
-    T_MAILDIR,
-    T_MBOX,
-    T_STDIN,
+	T_UNKNOWN,
+	T_MAILDIR,
+	T_MBOX,
+	T_STDIN,
 };
 
 enum MBOXSTATE {
-    ST_UNKNOWN,
-    ST_HEADER,
-    ST_BODY_AFTER_EMPTY_LINE,
-    ST_BODY,
+	ST_UNKNOWN,
+	ST_HEADER,
+	ST_BODY_AFTER_EMPTY_LINE,
+	ST_BODY,
 };
 
 #define FBUFSIZ		(BUFSIZ * 32)
@@ -76,6 +76,7 @@ private int	GetCur;
 private int	UseCL;
 private int	PreserveUnixFrom;
 private int	CreateMTime = TRUE;
+private int	FileMode = S_IRUSR | S_IWUSR;
 private int	Exit = 0;
 
 /****************************************************************
@@ -167,10 +168,12 @@ Gethomedir(void)
 private char *
 strdup(const char *str)
 {
+	int len = strlen(str);
 	char* t;
-	MALLOC(t, strlen(str) + 1);
+	MALLOC(t, len + 1);
 	if (t)
-		strcpy(t, str);
+		strncpy(t, len, str);
+	*(t + len) = NUL;
 	return t;
 }
 #endif
@@ -225,6 +228,7 @@ help_message[] = {
 	"    -c            Use Content-Length: field. (for mbox)",
 	"    -u            Don't create inboxdir/.mew-mtime file.",
 	"    -f            Preserve Unix From (Envelope Sender). (for mbox)",
+	"    -p <fmode>    Specify file permission. (for mbox)",
 	NULL
 };
 
@@ -291,14 +295,14 @@ search_mbox_path(void)
 	if ((home = Gethomedir()) != NULL) {
 		if (strlen(home) + 9 > PATH_MAX)
 			error("pathname too long (%s)", home);
-		sprintf(Mbox, "%s/%s", home, MAILDIR);
+		snprintf(Mbox, sizeof(Mbox), "%s/%s", home, MAILDIR);
 		if (check_mbox_type(Mbox) != T_UNKNOWN)
 			return;
 	}
 	if ((mail = getenv("MAIL")) != NULL) {
 		if (strlen(mail) + 1 > PATH_MAX)
 			error("pathname too long (%s)", mail);
-		sprintf(Mbox, mail);
+		STRCPY(Mbox, mail);
 		if (check_mbox_type(Mbox) != T_UNKNOWN)
 			return;
 	}
@@ -308,12 +312,12 @@ search_mbox_path(void)
 			if (strlen(mbox_path_list[i]) + strlen(user) + 1
 			    > PATH_MAX)
 				error("pathname too long (%s)", user);
-			sprintf(Mbox, "%s%s", mbox_path_list[i], user);
+			snprintf(Mbox, sizeof(Mbox), "%s%s", mbox_path_list[i], user);
 			if (check_mbox_type(Mbox) != T_UNKNOWN)
 				return;
 		}
 	}
-	sprintf(Mbox, ".");
+	snprintf(Mbox, sizeof(Mbox), ".");
 	return;
 }
 
@@ -346,7 +350,7 @@ private void
 init_env(int argc, char **argv)
 {
 	set_sighandler();
-	sprintf(InboxDir, ".");
+	snprintf(InboxDir, sizeof(InboxDir), ".");
 	MboxType = T_UNKNOWN;
 	Backup = FALSE;
 	UseCL = FALSE;
@@ -473,15 +477,15 @@ maildir_names(const char *maildir, char **newdir, char **curdir, char **tmpdir)
 		return -1;
 	if (newdir != NULL) {
 		MALLOC(*newdir, len);
-		sprintf(*newdir, "%s/%s", maildir, MAILDIR_NEW);
+		snprintf(*newdir, len, "%s/%s", maildir, MAILDIR_NEW);
 	}
 	if (curdir != NULL) {
 		MALLOC(*curdir, len);
-		sprintf(*curdir, "%s/%s", maildir, MAILDIR_CUR);
+		snprintf(*curdir, len, "%s/%s", maildir, MAILDIR_CUR);
 	}
 	if (tmpdir != NULL) {
 		MALLOC(*tmpdir, len);
-		sprintf(*tmpdir, "%s/%s", maildir, MAILDIR_TMP);
+		snprintf(*tmpdir, len, "%s/%s", maildir, MAILDIR_TMP);
 	}
 	return 0;
 }
@@ -492,10 +496,10 @@ new_inbox_file(int seq, char inboxfile[])
 {
 	char num[PATH_MAX];
 	do {
-		sprintf(num, "%d", ++seq);
+		snprintf(num, sizeof(num), "%d", ++seq);
 		if (strlen(InboxDir) + strlen(num) + 2 > PATH_MAX)
 			error("pathname too long (%s/%s)", InboxDir, num);
-		sprintf(inboxfile, "%s/%s", InboxDir, num);
+		snprintf(inboxfile, PATH_MAX, "%s/%s", InboxDir, num);
 		if (access(inboxfile, F_OK) && errno == ENOENT)
 			break;
 	} while (TRUE);
@@ -508,17 +512,15 @@ open_new_inbox_file(int *seq, char inboxfile[])
 {
 	char num[PATH_MAX];
 	int flag = O_EXCL | O_CREAT | O_WRONLY;
-	int mode = S_IRUSR | S_IRGRP | S_IROTH |
-		   S_IWUSR | S_IWGRP | S_IWOTH;
 	int fd;
 	FILE *fp = NULL;
 
 	for (;;) {
-		sprintf(num, "%d", ++*seq);
+		snprintf(num, sizeof(num), "%d", ++*seq);
 		if (strlen(InboxDir) + strlen(num) + 2 > PATH_MAX)
 			error("pathname too long (%s/%s)", InboxDir, num);
-		sprintf(inboxfile, "%s/%s", InboxDir, num);
-		if ((fd = open(inboxfile, flag, mode)) >= 0 ||
+		snprintf(inboxfile, PATH_MAX, "%s/%s", InboxDir, num);
+		if ((fd = open(inboxfile, flag, FileMode)) >= 0 ||
 		    errno != EEXIST)
 			break;
 		usleep(rand() % 199);
@@ -553,7 +555,7 @@ get_from_dir(int seq, char *fromdir, char *backupdir, int backup)
 		if (strlen(fromdir) + strlen(dp->d_name) + 2 > PATH_MAX)
 			error("pathname too long (%s/%s)",
 			      fromdir, dp->d_name);
-		sprintf(mailfile, "%s/%s", fromdir, dp->d_name);
+		snprintf(mailfile, sizeof(mailfile), "%s/%s", fromdir, dp->d_name);
 		if (stat(mailfile, &sb))
 			continue;
 		if (!(S_ISREG(sb.st_mode) && (sb.st_mode & S_IRUSR)))
@@ -577,12 +579,12 @@ get_from_dir(int seq, char *fromdir, char *backupdir, int backup)
 		if (strlen(fromdir) + strlen(list[i]) + 2 > PATH_MAX)
 			error("pathname too long (%s/%s)",
 			      fromdir, list[i]);
-		sprintf(mailfile, "%s/%s", fromdir, list[i]);
+		snprintf(mailfile, sizeof(mailfile), "%s/%s", fromdir, list[i]);
 		if (backup && backupdir != NULL) {
 			if (strlen(backupdir) + strlen(list[i]) + 6 > PATH_MAX)
 				error("pathname too long (%s/%s)",
 				      backupdir, list[i]);
-			sprintf(backupfile, "%s/%s:2,S", backupdir, list[i]);
+			snprintf(backupfile, sizeof(backupfile), "%s/%s:2,S", backupdir, list[i]);
 			movefile(mailfile, inboxfile, backupfile, backup);
 		}
 		else
@@ -649,7 +651,7 @@ process_mbox(int seq)
 
 	if (strlen(Mbox) + strlen(LOCK_SUFFIX) + 1 > PATH_MAX)
 		error("pathname too long (%s%s)", Mbox, LOCK_SUFFIX);
-	sprintf(MboxLock, "%s%s", Mbox, LOCK_SUFFIX);
+	snprintf(MboxLock, sizeof(MboxLock), "%s%s", Mbox, LOCK_SUFFIX);
 	if (lock_mbox(MboxLock))
 		MboxLock[0] = '\0'; /* doesn't need a lockfile, maybe. */
 
@@ -689,7 +691,7 @@ process_mbox(int seq)
 		case ST_HEADER:
 			if (strlen(ln) < 3 &&
 			    (ln[0] == '\n' || ln[0] == '\r')) {
-				strcpy(emptyline, ln);
+				STRCPY(emptyline, ln);
 				state = ST_BODY_AFTER_EMPTY_LINE;
 				break;
 			}
@@ -727,7 +729,7 @@ process_mbox(int seq)
 		case ST_BODY:
 			if (strlen(ln) < 3 &&
 			    (ln[0] == '\n' || ln[0] == '\r')) {
-				strcpy(emptyline, ln);
+				STRCPY(emptyline, ln);
 				state = ST_BODY_AFTER_EMPTY_LINE;
 			}
 			else
@@ -837,7 +839,7 @@ process(void)
 		return;		/* no new mail */
 	if (strlen(InboxDir) + strlen(MEW_MTIME_FILE) + 1 > PATH_MAX)
 		error("pathname too long (%s%s)", InboxDir, MEW_MTIME_FILE);
-	sprintf(mtimefile, "%s/%s", InboxDir, MEW_MTIME_FILE);
+	snprintf(mtimefile, sizeof(mtimefile), "%s/%s", InboxDir, MEW_MTIME_FILE);
 
 	if ((fp = fopen(mtimefile, FDWRITE)) == NULL)
 		error("can't create file (%s)", mtimefile);
@@ -876,7 +878,7 @@ main(int argc, char **argv)
 	warn_prog = progname;
 	init_env(argc, argv);
 
-	while ((ch = Getopt(argc, argv, "abcd:fhi:m:suvp")) != EOF) {
+	while ((ch = Getopt(argc, argv, "abcd:fhi:m:p:suv")) != EOF) {
 		switch (ch) {
 		case 'a':
 			GetCur = TRUE;
@@ -891,7 +893,7 @@ main(int argc, char **argv)
 		case 'm':
 			if (strlen(Optarg) + 1 > PATH_MAX)
 				error("pathname too long (%s)", Optarg);
-			sprintf(Mbox, "%s", Optarg);
+			snprintf(Mbox, sizeof(Mbox), "%s", Optarg);
 			break;
 		case 'f':
 			PreserveUnixFrom = TRUE;
@@ -899,12 +901,11 @@ main(int argc, char **argv)
 		case 'i':
 			if (strlen(Optarg) + 1 > PATH_MAX)
 				error("pathname too long (%s)", Optarg);
-			sprintf(InboxDir, "%s", Optarg);
+			snprintf(InboxDir, sizeof(InboxDir), "%s", Optarg);
+			break;
+		case 'p':
+			sscanf(Optarg, "%i", &FileMode);
 			break;
-		case 'p':	/* for debug */
-			printf("InboxDir: %s\n", InboxDir);
-			printf("Mbox: %s\n", Mbox);
-			exit(EXIT_SUCCESS);
 		case 's':
 			MboxType = T_STDIN;
 			break;
@@ -931,7 +932,7 @@ main(int argc, char **argv)
 }
 
 /* 
- * Copyright (C) 2001-2003 Mew developing team.
+ * Copyright (C) 2001-2005 Mew developing team.
  * All rights reserved.
  * 
  * Redistribution and use in source and binary forms, with or without
