@@ -66,10 +66,10 @@
 #define FILESEP '/'
 
 #define STRCMP(str1, str2) strncmp(str1, str2, sizeof(str2) - 1)
-
-#define STRDUP(dst, src) if (((dst) = strdup((src))) == NULL) warn_exit("memory fault.\n")
-#define MALLOC(p, siz) if (((p) = malloc((siz))) == NULL) warn_exit("memory fault.\n")
-#define REALLOC(p, siz) if (((p) = realloc((p), (siz))) == NULL) warn_exit("memory fault.\n")
+#define STRCPY(dst, src) do {strncpy(dst, src, sizeof(dst) - 1); dst[sizeof(dst) -1] = NUL;} while (0);
+#define STRDUP(dst, src) if (((dst) = strdup((src))) == NULL) warn_exit("memory fault.")
+#define MALLOC(p, siz) if (((p) = malloc((siz))) == NULL) warn_exit("memory fault.")
+#define REALLOC(p, siz) if (((p) = realloc((p), (siz))) == NULL) warn_exit("memory fault.")
 
 #ifndef HAVE_STRNCASECMP
 # ifdef HAVE_STRNICMP
