@@ -3,14 +3,13 @@
  *
  * Author:  Kazu Yamamoto <Kazu@Mew.org>
  * Created: Jul  7, 2000
- * Revised: Mar 14, 2003
  *
  * Code:
  */
 
 #include "mew.h"
 
-private char version_message[] = "version 4.1 20030314 Kazu Yamamoto";
+private char version_message[] = "version 4.2 20050107 Kazu Yamamoto";
 
 #ifdef HAVE_UNISTD_H
 # include <sys/types.h>
@@ -209,14 +208,14 @@ ch_home()
 	if(home == NULL || home[0] == NUL) {
 		struct passwd *pw = getpwuid(getuid());
 		if(pw == NULL)
-			warn_exit("failed in getting home directory.\n");
+			warn_exit("failed in getting home directory.");
 		home = pw->pw_dir;
 	}
 #endif /* HAVE_GETPWUID */
 	if (home == NULL)
-		warn_exit("can't change directory to home.\n");
+		warn_exit("can't change directory to home.");
 	if (chdir(home) != 0)
-		warn_exit("can't change directory to %s.\n", home);
+		warn_exit("can't change directory to %s.", home);
 }
 
 private void
@@ -224,7 +223,7 @@ ch_mail_home(char *dir)
 {
 	char *p = dir + 1, c;
 
-	if (dir == NULL) warn_exit("%s not exist.\n", dir);
+	if (dir == NULL) warn_exit("%s not exist.", dir);
 	c = *dir;
 	switch (c) {
 	case '~':
@@ -232,20 +231,20 @@ ch_mail_home(char *dir)
 		if (*p == NUL)
 			break;
 		if (*p++ != FILESEP)
-			warn_exit("can't change directory to %s.\n", dir);
+			warn_exit("can't change directory to %s.", dir);
 		if (*p == NUL)
 			break;
 		if (chdir(p) != 0)
-			warn_exit("can't change directory to %s.\n", dir);
+			warn_exit("can't change directory to %s.", dir);
 		break;
 	case FILESEP:
 		if (chdir(dir) != 0)
-			warn_exit("can't change directory to %s.\n", dir);
+			warn_exit("can't change directory to %s.", dir);
 		break;
 	default:
 		ch_home();
 		if (chdir(dir) != 0)
-			warn_exit("can't change directory to %s.\n", dir);
+			warn_exit("can't change directory to %s.", dir);
 		break;
 	}
 }
@@ -260,22 +259,22 @@ ch_folder(char *folder)
 		if (p == NUL)
 			break;
 		if (chdir(p) != 0)
-			warn_exit("can't change folder to %s.\n", folder);
+			warn_exit("can't change folder to %s.", folder);
 		break;
 	case '~':
 		ch_home();
 		if (*p == NUL)
 			break;
 		if (*p++ != FILESEP)
-			warn_exit("can't change folder to %s.\n", folder);
+			warn_exit("can't change folder to %s.", folder);
 		if (*p == NUL)
 			break;
 		if (chdir(p) != 0)
-			warn_exit("can't change folder to %s.\n", folder);
+			warn_exit("can't change folder to %s.", folder);
 		break;
 	default:
 		if (chdir(folder) != 0)
-			warn_exit("can't change folder to %s.\n", folder);
+			warn_exit("can't change folder to %s.", folder);
 		break;
 	}
 }
@@ -480,7 +479,7 @@ print_field(char *buf, int lim, char *fname, char *fld)
 	printf("Filename: %s\n", fname);
 	for (i = 0; i < Scan_ctx_fld_num; i++)
 		if (Scan_ctx_beg[i] != NULL) {
-			if (i == Scan_ctx_ref_idx) printf(REFERENCES);
+			if (i == Scan_ctx_ref_idx) printf("%s", REFERENCES);
 			p = Scan_ctx_beg[i];
 			while (p < Scan_ctx_end[i])
 				putchar(*p++);
@@ -726,7 +725,7 @@ scan_folder(struct fld_rng *fr) {
 	ch_folder(fr->folder);
 
 	if ((dirp = opendir(".")) == NULL)
-		warn_exit("can't open folder: %s.\n", fr->folder);
+		warn_exit("can't open folder: %s.", fr->folder);
 
 	while ((dp = readdir(dirp)) != NULL) {
 		fname = dp->d_name;
@@ -785,11 +784,11 @@ scan_getfile(char **filename, char **foldername)
 	*foldername = Folders[j - 1].folder;
 					    
 	while (i < Scan_ctx_messages) {
-		sprintf(Buf_filenm, "%d", *(Scan_ctx_buf + i));
+		snprintf(Buf_filenm, sizeof(Buf_filenm), "%d", *(Scan_ctx_buf + i));
 		fp = fopen(Buf_filenm, FDREAD);
 		if (fp == NULL) {
 			/* for invalid cache messages */
-			sprintf(Buf_filenm, "0%d", *(Scan_ctx_buf + i));
+			snprintf(Buf_filenm, sizeof(Buf_filenm), "0%d", *(Scan_ctx_buf + i));
 			fp = fopen(Buf_filenm, FDREAD);
 			if (fp == NULL) {
 			  i++;
@@ -817,13 +816,13 @@ exec_init(unsigned int num) /* num == 0 */
 	int pipes[2];
 
 	if (strlen(Folders[0].folder) >= sizeof(Current_folder))
-		warn_exit("folder name is too long.\n");
-	strcpy(Current_folder, Folders[0].folder);
+		warn_exit("folder name is too long.");
+	STRCPY(Current_folder, Folders[0].folder);
 	ch_folder(Current_folder);
 
-	if (pipe(pipes) != 0) warn_exit("can't open pipe.\n");
+	if (pipe(pipes) != 0) warn_exit("can't open pipe.");
 	childpid = FORK();
-	if (childpid < 0) warn_exit("can't fork.\n");
+	if (childpid < 0) warn_exit("can't fork.");
 
 	if (childpid == 0) { /* I'm the child. */
 		int i = 0;
@@ -848,7 +847,7 @@ exec_init(unsigned int num) /* num == 0 */
 		Argvec[i++] = NULL;
 		
 		execvp(Exec_cmd, Argvec);
-		warn_exit("'%s' command not found.\n", Exec_cmd);
+		warn_exit("'%s' command not found.", Exec_cmd);
 	}
 
 	/* I'm the parent. */
@@ -861,8 +860,8 @@ private void
 exec_init(unsigned int num) /* num == 0 */
 {
 	if (strlen(Folders[0].folder) >= sizeof(Current_folder))
-		warn_exit("folder name is too long.\n");
-	strcpy(Current_folder, Folders[0].folder);
+		warn_exit("folder name is too long.");
+	STRCPY(Current_folder, Folders[0].folder);
 	ch_folder(Current_folder);
 }
 #endif /* HAVE_FORK */
@@ -886,8 +885,8 @@ exec_getfile(char **filename, char **foldername)
 			p = p + strlen(CHDIR);
 			while (*p == SP || *p == TAB) p++;
 			if (strlen(p) >= sizeof(Current_folder))
-				warn_exit("folder name is too long.\n");
-			strcpy(Current_folder, p);
+				warn_exit("folder name is too long.");
+			STRCPY(Current_folder, p);
 			ch_folder(Current_folder);
 			*foldername = Current_folder;
 			continue;
@@ -914,11 +913,11 @@ stdin_init(unsigned int num) /* num == 0 */
 {
 	if (strcmp(Input_file, STDINFILE) != 0)
 		if (freopen(Input_file, FDREAD, stdin) == NULL)
-			warn_exit("can't open %s.\n", Input_file);
+			warn_exit("can't open %s.", Input_file);
 
 	if (strlen(Folders[0].folder) >= sizeof(Current_folder))
-		warn_exit("folder name is too long.\n");
-	strcpy(Current_folder, Folders[0].folder);
+		warn_exit("folder name is too long.");
+	STRCPY(Current_folder, Folders[0].folder);
 	ch_folder(Current_folder);
 }
 
@@ -1027,7 +1026,7 @@ main(int argc, char **argv)
 			break;
 		case 's':
 			if (lim >= MAX_FOLDER)
-				warn_exit("too many folders.\n");
+				warn_exit("too many folders.");
 			STRDUP(fld_rng, Optarg);
 			set_fld_rng(&Folders[lim++], fld_rng, NULL);
 			sflag++;
@@ -1063,7 +1062,7 @@ main(int argc, char **argv)
 			exit(EXIT_FAILURE);
 		}
 	else if (rest != 0)
-		warn_exit("the 's' option can't co-exist with arguments.\n");
+		warn_exit("the 's' option can't co-exist with arguments.");
 
 	if (Input_file != NULL) {
 		func_init = stdin_init;
@@ -1110,7 +1109,7 @@ main(int argc, char **argv)
 }
 
 /* 
- * Copyright (C) 2000-2003 Mew developing team.
+ * Copyright (C) 2000-2005 Mew developing team.
  * All rights reserved.
  * 
  * Redistribution and use in source and binary forms, with or without
