@@ -3,7 +3,6 @@
  *
  * Author:  Kazu Yamamoto <Kazu@Mew.org>
  * Created: Sep 29, 2000
- * Revised: Jul 10, 2001
  *
  * Code:
  */
@@ -25,7 +24,7 @@ char *warn_prog;
 public char *
 getprognm(char *filename)
 {
-	char *p, *q;
+	unsigned char *p, *q;
 
 	if ((p = strrchr(filename, FILESEP)) != NULL)
 		p++;
@@ -49,6 +48,7 @@ warning(const char *fmt, ...)
 	if (fmt != NULL)
                 vfprintf(stderr, fmt, ap);
 	va_end(ap);
+	fprintf(stderr, "\n");
 }
 
 public void
@@ -62,54 +62,69 @@ warn_exit(const char *fmt, ...)
 	if (fmt != NULL)
                 vfprintf(stderr, fmt, ap);
 	va_end(ap);
+	fprintf(stderr, "\n");
 
 	exit(EXIT_FAILURE);
 }
 
+#ifndef HAVE_SNPRINTF
+public int
+snprintf(char *buf, int len, const char *fmt, ...)
+{
+	int ret;
+	va_list ap;
+
+	va_start(ap, fmt);
+	ret = vsprintf(buf, fmt, ap);
+	va_end(ap);
+	return ret;
+}
+#endif
+
 #ifndef HAVE_FGETLN
 private char*
 fgetln(FILE *fp, size_t *len)
 {
-    static size_t bufsize = 0;
-    static char *buf = NULL;
-    char tmp[BUFSIZ];
-    size_t readlen;
+	static size_t bufsize = 0;
+	static char *buf = NULL;
+	char tmp[BUFSIZ];
+	size_t readlen;
 
-    if (buf == NULL) {
-	bufsize = BUFSIZ;
-	MALLOC(buf, bufsize);
-    }
-
-    *len = 0;
-    while (1) {
-	if (fgets(tmp, BUFSIZ, fp) == NULL)
-	    return NULL;
-	readlen = strlen(tmp);
-
-	if (*len + readlen > bufsize) {
-	    bufsize += BUFSIZ;
-	    REALLOC(buf, bufsize);
+	if (buf == NULL) {
+		bufsize = BUFSIZ;
+		MALLOC(buf, bufsize);
 	}
-	memmove(&buf[*len], tmp, readlen);
-	*len += readlen;
-	if (readlen < BUFSIZ - 1 || tmp[BUFSIZ - 2] == '\n')
-	    break;
-    }
-    return buf;
+
+	*len = 0;
+	while (1) {
+		if (fgets(tmp, BUFSIZ, fp) == NULL)
+			return NULL;
+		readlen = strlen(tmp);
+
+		if (*len + readlen > bufsize) {
+			bufsize += BUFSIZ;
+			REALLOC(buf, bufsize);
+		}
+		memmove(&buf[*len], tmp, readlen);
+		*len += readlen;
+		if (readlen < BUFSIZ - 1 || tmp[BUFSIZ - 2] == '\n')
+			break;
+	}
+	return buf;
 }
 #endif
 
 char*
 getline(FILE* fp)
 {
-    char *s, *t;
-    size_t len;
-    if ((t = fgetln(fp, &len)) == NULL)
-	return NULL;
-    MALLOC(s, len+1);
-    memmove(s, t, len);
-    s[len] = '\0';
-    return s;
+	char *s, *t;
+	size_t len;
+	if ((t = fgetln(fp, &len)) == NULL)
+		return NULL;
+	MALLOC(s, len+1);
+	memmove(s, t, len);
+	s[len] = '\0';
+	return s;
 }
 
 int  Optind = 1;
@@ -131,12 +146,12 @@ Getopt(int argc, char *argv[], const char *fmt)
 	if (c == NUL)
 		return EOF;
 	if (*(p + 1) != NUL)
-		warn_exit("unknown long option '-%s'.\n", p);
+		warn_exit("unknown long option '-%s'.", p);
 	if ((q = strchr(fmt, c)) == NULL)
-		warn_exit("unknown option '-%c'.\n", c);
+		warn_exit("unknown option '-%c'.", c);
 	if (++q != NULL && *q == ':') {
 		if (++Optind >= argc)
-			warn_exit("no parameter for '-%c'.\n", c);
+			warn_exit("no parameter for '-%c'.", c);
 		Optarg = argv[Optind];
 	}
 	Optind++;
@@ -144,7 +159,7 @@ Getopt(int argc, char *argv[], const char *fmt)
 }
 
 /* 
- * Copyright (C) 2000-2003 Mew developing team.
+ * Copyright (C) 2000-2005 Mew developing team.
  * All rights reserved.
  * 
  * Redistribution and use in source and binary forms, with or without
