@@ -86,4 +86,7 @@
 /* generic windows header */
 #include <windows.h>
 
+/* windows specific definitions */
+#include <w32.h>
+
 #endif /* !__CONFIG_H__ */
