@@ -50,7 +50,7 @@
    (mew-caesar-ext-prog
     'ext)
    (t
-    (message "mew-caesar: program is not found.")
+    (message "mew-caesar: program is not found")
     nil))
   "mew-caesar function select.
  Usually auto selected, which
@@ -122,7 +122,7 @@
   "Open a new Caesar encrypt file into a buffer on \".\" in attachments."
   (interactive)
   (if (not (mew-attach-not-line012-1))
-      (message "Can't find a new file here.")
+      (message "Cannot find a new file here")
     (let* ((nums (mew-syntax-nums))
 	   (subdir (mew-attach-expand-path mew-encode-syntax nums))
 	   (attachdir (mew-attachdir))
@@ -133,7 +133,7 @@
       ;; attachdir / file
       (setq filepath (mew-random-filename attachdir 1 nil mew-caesar-rot13-suffix))
       (if (null filepath)
-	  (message "Could not make a text file, sorry.")
+	  (message "Could not make a text file, sorry")
 	(setq file (file-name-nondirectory filepath))
 	(setq mew-encode-syntax
 	      (mew-syntax-insert-entry
@@ -203,7 +203,7 @@
 		t t nil
 		mew-caesar-ext-prog-arg))))
      (t
-      (message "mew-caesar: program is not found.")))
+      (message "mew-caesar: program is not found")))
     ))
 
 (provide 'mew-caesar)
