@@ -64,13 +64,13 @@ Windows $B$N?M$O(B \"nmz-mew-summary-fixer\" $B$N$h$&$K3HD%;R$rL5$/$7$?J}$,9,
 	 (progn
 	   (setq mew-nmz-fixer-process nil)
 	   (and interactive-p
-		(message "Set %s to free." mew-nmz-prog-fixer)))
+		(message "Set %s to free" mew-nmz-prog-fixer)))
        (if (not (and fld fixer))
 	   (and interactive-p
-		(message "Can not exec %s." mew-nmz-prog-fixer))
+		(message "Cannot exec %s" mew-nmz-prog-fixer))
 	 (setq nmzdir (mew-nmz-expand-folder fld))
 	 (if mew-nmz-fixer-process
-	     (message "Another fixer running.")
+	     (message "Another fixer running")
 	   (if (and
 		nmzdir
 		(file-exists-p nmzdir)
@@ -91,7 +91,7 @@ Windows $B$N?M$O(B \"nmz-mew-summary-fixer\" $B$N$h$&$K3HD%;R$rL5$/$7$?J}$,9,
 				      (list (mew-expand-folder fld) nmzdir))))
 		 (set-process-sentinel mew-nmz-fixer-process 'mew-nmz-fixer-sentinel))
 	     (and interactive-p
-		  (message "Can not exec %s at %s." mew-nmz-prog-fixer nmzdir)))))))))
+		  (message "Cannot exec %s at %s" mew-nmz-prog-fixer nmzdir)))))))))
 
 (defun mew-nmz-fixer-sentinel (process event)
   (save-excursion
