@@ -2,11 +2,11 @@
 
 ;; Author:  Takashi P.KATOH <p-katoh@shiratori.riec.tohoku.ac.jp>
 ;; Created: Oct 22, 1998
-;; Revised: Oct 25, 1999
+;; Revised: Jan 06, 2004
 
 ;;; Code:
 
-(defconst mew-refile-view-version "mew-refile-view.el version 0.06")
+(defconst mew-refile-view-version "mew-refile-view.el version 0.07")
 
 (require 'mew)
 (if mew-xemacs-p (require 'easymenu))
@@ -81,9 +81,13 @@ will be also shown.")
 ;;; Refile view mode
 ;;;
 
+(defun mew-re-search-forward-and-backward (regexp bound noerror)
+  (or (re-search-forward regexp bound noerror)
+      (re-search-backward regexp bound noerror)))
+  
 ;; -> mew-vars ?
 (defconst mew-refile-view-folder-regex "^[*+=]")
-(defvar original-folder nil)
+(defvar mew-original-folder nil)
 
 (defun mew-assoc-add (key alist mem)
   (append (list (append (or (assoc key alist) (list key)) (list mem)))
@@ -108,7 +112,7 @@ will be also shown.")
 
 (defun mew-refile-view (&optional prefix)
   (interactive "P")
-  (mew-summary-or-thread
+  (mew-pickable
    (if (interactive-p)
        (mew-current-set-window-config))
    (let* ((folder (buffer-name))
@@ -176,16 +180,26 @@ will be also shown.")
 		   numlist (cdr numlist))
 	     ;;
 	     (set-buffer (get-buffer folder))
-	     (let ((mew-summary-jump-message-then-display nil))
-	       (mew-summary-jump-message (int-to-string num)))
-	     (setq summary (buffer-substring 
-			    (point) (save-excursion (end-of-line) (point))))
-	     ;;
-	     (set-buffer view)
-	     (insert summary)
-	     (let ((mew-highlight-mark-folder-list (list bufname)))
-	       (mew-mark-unmark))
-	     (insert "\n"))
+	     ;; Mew4
+	     (when (mew-re-search-forward-and-backward
+                    (mew-regex-sumsyn-msg (int-to-string num)) nil t)
+	       (if (mew-thread-p)
+		   (setq summary
+			 (concat
+			  (mew-buffer-substring (line-beginning-position)
+						(progn (move-to-column (mew-vinfo-get-column))
+						       (point)))
+			  (mew-buffer-substring (let ((mew-use-thread-cursor t))
+						  (progn (mew-thread-move-cursor) (point)))
+						(line-end-position))))
+		 (setq summary (mew-buffer-substring (line-beginning-position)
+						     (line-end-position))))
+	       ;;
+	       (set-buffer view)
+	       (insert summary)
+	       (let ((mew-highlight-mark-folder-list (list bufname)))
+		 (mew-mark-unmark))
+	       (insert "\n")))
 	   (insert "\n")
 	   (setq alist (cdr alist)))
 	 (goto-char (point-min))
@@ -200,23 +214,23 @@ will be also shown.")
   (let (num)
     (save-excursion
       (beginning-of-line)
-      (setq num (if (looking-at mew-regex-msg)
-		    (match-string 1))))
-    (if (not (and original-folder (get-buffer original-folder)))
+      (setq num (if (looking-at (concat "^[^\r\n]+" mew-regex-sumsyn-short))
+		    (mew-match-string 2))))
+    (if (not (and mew-original-folder (get-buffer mew-original-folder)))
 	(progn
-	  (message "No Summary buffer for %s" original-folder)
+	  (message "No Summary buffer for %s" mew-original-folder)
 	  nil)
-      (if (get-buffer-window original-folder)
-	  (select-window (get-buffer-window original-folder))
-	(mew-summary-switch-to-folder original-folder))
-      (if num (mew-summary-jump-message num))
+      (if (get-buffer-window mew-original-folder)
+	  (select-window (get-buffer-window mew-original-folder))
+	(mew-summary-switch-to-folder mew-original-folder))
+      (if num (mew-summary-move-and-display num))
       t)))
 
 (defun mew-refile-view-again ()
   (interactive)
-  (if (not (and original-folder (get-buffer original-folder)))
-      (message "No Summary buffer for %s" original-folder)
-    (set-buffer original-folder)
+  (if (not (and mew-original-folder (get-buffer mew-original-folder)))
+      (message "No Summary buffer for %s" mew-original-folder)
+    (set-buffer mew-original-folder)
     (mew-refile-view)))
 
 (defun mew-refile-view-quit ()
@@ -239,7 +253,7 @@ will be also shown.")
   (interactive)
   (let ((orig (point)))
     (end-of-line)
-    (if (re-search-forward mew-regex-msg nil t)
+    (if (re-search-forward mew-regex-sumsyn-short nil t)
 	(beginning-of-line)
       (goto-char orig))))
 
@@ -248,7 +262,7 @@ will be also shown.")
   (interactive)
   (let ((orig (point)))
     (beginning-of-line)
-    (if (re-search-backward mew-regex-msg nil t)
+    (if (re-search-backward mew-regex-sumsyn-short nil t)
 	(beginning-of-line)
       (goto-char orig))))
 
@@ -271,12 +285,12 @@ will be also shown.")
 
 (defun mew-refile-view-exec ()
   (interactive)
-  (if (not (and original-folder (get-buffer original-folder)))
-      (message "No Summary buffer for %s" original-folder)
+  (if (not (and mew-original-folder (get-buffer mew-original-folder)))
+      (message "No Summary buffer for %s" mew-original-folder)
     (if (or (not mew-refile-view-exec-confirm)
 	    ;; or yes-or-no-p?
 	    (y-or-n-p "Execute refiling for these messages? "))
-	(let ((fld original-folder)
+	(let ((fld mew-original-folder)
 	      thread)
 	  (save-excursion
 	    (if (save-excursion
@@ -321,9 +335,9 @@ If this message has multi-refile folders, remove one of them."
   (let ((orig-point (point))
 	(orig-buff (current-buffer))
 	msg reffld bufref fld ofld tmp)
-    (if (not (looking-at mew-regex-msg))
+    (if (not (looking-at (concat "^[^\r\n]+" mew-regex-sumsyn-short)))
 	(message "No message")
-      (setq msg (buffer-substring (match-beginning 1) (match-end 1)))
+      (setq msg (mew-match-string 2))
       (if one
 	  (save-excursion
 	    (if (re-search-backward
@@ -333,7 +347,7 @@ If this message has multi-refile folders, remove one of them."
 					       (match-end 0))))))
       ;; in mew summary buffer
       (if (mew-refile-view-goto-summary)
-	  (mew-summary-or-thread
+	  (mew-pickable
 	   (cond
 	    ((eq op 'refile)
 	     (mew-summary-refile))
@@ -401,8 +415,8 @@ Q	Exit.
   (setq selective-display t)
   (setq selective-display-ellipses nil)
   (setq truncate-lines t)
-  (make-local-variable 'original-folder)
-  (setq original-folder folder)
+  (make-local-variable 'mew-original-folder)
+  (setq mew-original-folder folder)
   (mew-buffers-setup (buffer-name))
   (run-hooks 'mew-refile-view-mode-hook))
 
