@@ -132,7 +132,8 @@
 
 (defun mew-addrbook-clean-up ()
   (remove-hook 'kill-emacs-hook 'mew-addrbook-clean-up)
-  (mew-lisp-save mew-alias-auto-file mew-alias-auto-alist)
+  (when mew-alias-auto-alist
+    (mew-lisp-save mew-alias-auto-file mew-alias-auto-alist))
   (setq mew-alias-auto-alist nil))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
@@ -279,7 +280,7 @@ returned."
 	    (mew-insert-file-contents chr)
 	    (setq files (cons chr files))))
 	(goto-char (point-max))))
-    ;; remove commets
+    ;; remove comments
     (goto-char (point-min))
     (while (re-search-forward cregex nil t)
       (setq beg (match-beginning 0))
@@ -301,7 +302,7 @@ returned."
       (end-of-line)
       (forward-char 1)
       (delete-backward-char 1))
-    ;; replace ", " to "\0" inside/ouside quote.
+    ;; replace ", " to "\0" inside/outside quote.
     (goto-char (point-min))
     (while (re-search-forward ",[ \t]+" nil t)
       (replace-match ",\0" nil t))
@@ -567,7 +568,7 @@ reflected."
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 1999-2003 Mew developing team.
+;; Copyright (C) 1999-2005 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
