@@ -243,7 +243,7 @@
            (mew-header-encode-string1
 	    charset b-or-q fun hcs (substring str 0 med) key-len)
            (mew-header-encode-string1
-	    charset b-or-q fun hcs (substring str med nil))))
+	    charset b-or-q fun hcs (substring str med))))
       (list encoded-word))))
 
 (defun mew-header-encode-split-string (str)
@@ -258,7 +258,7 @@
 			(cons (substring str start beg) ret))))
       (setq start end))
     (if (/= start (length str))
-	(setq ret (cons (substring str start nil) ret)))
+	(setq ret (cons (substring str start) ret)))
     (nreverse ret)))
 
 (defun mew-header-encode-comma-text (str)
@@ -508,7 +508,7 @@
 		      (delete-char 1)
 		      (insert "\t"))))
 	    ;; Ugh!
-	    (if (re-search-forward "[ \t]" limit2 t) ;; hold on ayway
+	    (if (re-search-forward "[ \t]" limit2 t) ;; hold on anyway
 		(progn
 		  (backward-char)
 		  (insert "\n")
@@ -729,7 +729,7 @@ That is, each line may be more than 75."
 	  ;;
 	  (goto-char (point-min))
 	  ;; Perfect regular expression for quoted strings.
-	  ;; See "Marstering Regular Expressions", O'REILLY
+	  ;; See "Mastering Regular Expressions", O'REILLY
 	  (while (re-search-forward "\"\\([^\"\\\\]\\|\\\\.\\)*\"" nil t)
 	    (goto-char (match-beginning 0))
 	    (insert "\n")
@@ -887,7 +887,7 @@ That is, each line may be more than 75."
 	  (if asterisk
 	      (setq section 0)
 	    (setq section nil))
-	(setq section (string-to-int (substring section 1 nil))))
+	(setq section (string-to-int (substring section 1))))
       (if (null asterisk)
 	  ;; delete quote
 	  (progn
@@ -942,7 +942,7 @@ That is, each line may be more than 75."
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 1997-2003 Mew developing team.
+;; Copyright (C) 1997-2005 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
