@@ -33,7 +33,7 @@
       (forward-line -1))
     (if (looking-at "\\([^:]*:\\)")
 	(mew-field-get-func (match-string 1) switch)
-      nil))) ;; what a case reachs here?
+      nil))) ;; what a case reaches here?
   
 ;;
 ;; Window management for completion candidates
@@ -119,6 +119,7 @@ is inserted before the cursor, the short name is expanded to its address."
        nil))))
 
 (defun mew-complete-newsgroups ()
+  "Newsgroup complete function."
   (interactive)
   (let ((word (mew-delete-backward-char)))
     (if (null word)
@@ -144,12 +145,32 @@ is inserted before the cursor, the short name is expanded to its address."
     	(completion-ignore-case mew-complete-address-ignore-case))
     (if (null word)
 	(tab-to-tab-stop)
-      (if (string-match "@." word)
-	  (insert (or (mew-addrbook-alias-next word mew-addrbook-alist) word))
-	(mew-complete
-	 word mew-addrbook-alist "alias" ?@ nil nil
-	 'mew-addrbook-alias-get
-	 'mew-addrbook-alias-hit)))))
+      (if mew-use-full-alias
+	  (mew-complete
+	   word mew-addrbook-alist "alias" nil nil nil
+	   'mew-addrbook-alias-get
+	   'mew-addrbook-alias-hit)
+	(if (string-match "@." word)
+	    (insert (or (mew-addrbook-alias-next word mew-addrbook-alist) word))
+	  (mew-complete
+	   word mew-addrbook-alist "alias" ?@ nil nil
+	   'mew-addrbook-alias-get
+	   'mew-addrbook-alias-hit))))))
+
+(defun mew-draft-addrbook-expand ()
+  (interactive)
+  (mew-draft-set-completion-ignore-case mew-complete-address-ignore-case)
+  (let ((word (mew-delete-backward-char))
+    	(completion-ignore-case mew-complete-address-ignore-case)
+	try)
+    (if (null word)
+	(message "No expand key")
+      (setq try (try-completion word mew-addrbook-alist))
+      (if (or (eq try t)
+	      (and (stringp try) (string= word try)))
+	  (insert (mew-addrbook-alias-get word mew-addrbook-alist))
+	(insert word)
+	(message "'%s' cannot be expanded" word)))))
 
 (defun mew-complete-local-folder ()
   "Local folder complete function."
@@ -195,26 +216,25 @@ is inserted before the cursor, the short name is expanded to its address."
 (defun mew-complete-folder2 ()
   (let ((word (mew-delete-backward-char nil ", \t\n"))
 	(completion-ignore-case mew-complete-folder-ignore-case)
-	case fld case-fld)
+	case folder)
     (cond
      ((null word)
       (mew-complete-window-show mew-config-cases2))
-     ((setq case-fld (mew-folder-case word))
-      (setq case (car case-fld))
-      (setq fld (cdr case-fld))
+     ((setq case (mew-case:folder-case word))
+      (setq folder (mew-case:folder-folder word))
       (cond
-       ((mew-folder-localp fld)
-	(mew-complete2 fld (mew-local-folder-alist) case))
-       ((mew-folder-popp fld)
-	(mew-complete2 fld (mew-pop-folder-alist) case))
-       ((mew-folder-nntpp fld)
-	(mew-complete2 fld (mew-nntp-folder-alist case) case))
-       ((mew-folder-imapp fld)
-	(mew-complete2 fld (mew-imap-folder-alist case) case))
-       ((mew-folder-virtualp fld)
+       ((mew-folder-localp folder)
+	(mew-complete2 folder (mew-local-folder-alist) case))
+       ((mew-folder-popp folder)
+	(mew-complete2 folder (mew-pop-folder-alist) case))
+       ((mew-folder-nntpp folder)
+	(mew-complete2 folder (mew-nntp-folder-alist case) case))
+       ((mew-folder-imapp folder)
+	(mew-complete2 folder (mew-imap-folder-alist case) case))
+       ((mew-folder-virtualp folder)
 	(mew-complete
 	 word (mew-buffer-list "^\\*" t 'mew-virtual-mode) "folder" nil))
-       ((string= fld "")
+       ((string= folder "")
 	(insert word)
 	(mew-complete-window-show
 	 (mapcar (lambda (x) (concat case ":" x)) mew-folder-prefixes)))
@@ -317,35 +337,51 @@ the cursor is inserted."
        "domain"
        t))))) ;; use cdr
 
-(defun mew-circular-complete (msg clist cname &optional here)
-  "General circular complete function to call mew-complete."
+(defun mew-circular-complete (msg sym &optional minibuf) ;; xxx msg
+  "General circular complete function."
   (interactive)
-  (let ((str (mew-delete-value here)))
-    (if (null str)
-	(if (car clist)
-	    (insert (car clist))
-	  (message "For circular completion, set %s" cname))
-      (mew-complete
-       str
-       (mew-slide-pair clist)
-       msg
-       t)))) ;; use cdr
+  (let ((name (symbol-name sym))
+	(val (symbol-value sym))
+	str alst match)
+    (if (null val)
+	(mew-temp-minibuffer-message (format "[Set '%s']" name))
+      (setq str (mew-delete-value nil minibuf))
+      (setq alst (mew-slide-pair val))
+      (if (or (null str) ;; draft
+	      (and (string= str "") (null (assoc "" alst)))) ;; minibuf
+	  (insert (car val))
+	(setq match (assoc str alst))
+	(if match
+	    (insert (cdr match))
+	  (insert str)
+	  (mew-temp-minibuffer-message (format "[No matching %s]" msg)))))))
 
 (defun mew-circular-complete-from ()
   "Circular complete function for From:."
   (interactive)
-  (mew-circular-complete "from" mew-from-list "mew-from-list"))
+  (mew-circular-complete "from" 'mew-from-list))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
 ;;; Circular completion function for the minibuffer only
 ;;;
 
-(defun mew-circular-complete-case ()
+(defvar mew-circular-complete-function nil)
+
+(defun mew-circular-complete-switch ()
+  "A switch function to call a function defined to
+'mew-circular-complete-function'."
   (interactive)
+  (if mew-circular-complete-function (funcall mew-circular-complete-function)))
+
+(defun mew-circular-complete-pick-pattern ()
+  (mew-circular-complete "pick pattern" 'mew-pick-pattern-list 'minibuf))
+
+(defun mew-circular-complete-case ()
+  (mew-circular-complete "case" 'mew-config-cases 'minibuf))
+
+(defun mew-circular-complete-case: ()
   (cond
-   ((null mew-input-folder-circular-case)
-    ())
    ((eq mew-input-complete-function 'mew-complete-local-folder)
     ())
    (mew-input-folder-search-direction
@@ -533,9 +569,10 @@ the name exists."
       (mew-complete-window-show all)
       (if (and (mew-characterp EXPAND-CHAR) (funcall fhit cmp ALIST))
 	  (message
-	   (substitute-command-keys
-	    "To expand '%s', type '%c' then '\\<mew-draft-header-map>\\[mew-draft-header-comp]'.")
-	   cmp EXPAND-CHAR)))
+	   "To expand '%s', type '%c' then '%s'"
+	   cmp EXPAND-CHAR
+ 	   (substitute-command-keys
+	    "\\<mew-draft-header-map>\\[mew-draft-header-comp]"))))
      ;; no candidate
      (t
       (insert WORD)
@@ -589,7 +626,11 @@ the name exists."
     (let ((inhibit-quit t))
       (mew-let-user-read)
       (delete-region savemax (point-max))
-      (if quit-flag (setq quit-flag nil	unread-command-events 7)))))
+      (when quit-flag
+	(setq quit-flag nil)
+	(setq unread-command-events (list (if mew-xemacs-p
+					      (character-to-event 7)
+					    7))))))) ;; 7 == C-g
 
 ;;
 ;; Extracting completion key
@@ -647,25 +688,30 @@ the name exists."
 	(mew-capitalize (mew-buffer-substring (point) pos))
       (delete-region (point) pos))))
 
-(defun mew-delete-value (&optional here)
+(defun mew-delete-value (&optional here minibuf)
   (beginning-of-line)
-  (if (not (looking-at "[^:]+:"))
-      ()
-    (goto-char (match-end 0))
-    (if (looking-at "[ \t]")
-	(forward-char 1)
-      (insert " "))
-    (if (eolp)
-	nil
+  (if minibuf
       (let ((start (point)) ret)
 	(end-of-line)
-	(if (and here (re-search-backward (regexp-quote here) start t))
-	    (progn
-	      (setq start (1+ (point)))
-	      (end-of-line)))
 	(setq ret (mew-buffer-substring start (point)))
 	(delete-region start (point))
-	ret))))
+	ret)
+    (when (looking-at "[^:]+:")
+      (goto-char (match-end 0))
+      (if (looking-at "[ \t]")
+	  (forward-char 1)
+	(insert " "))
+      (if (eolp)
+	  nil
+	(let ((start (point)) ret)
+	  (end-of-line)
+	  (if (and here (re-search-backward (regexp-quote here) start t))
+	      (progn
+		(setq start (1+ (point)))
+		(end-of-line)))
+	  (setq ret (mew-buffer-substring start (point)))
+	  (delete-region start (point))
+	  ret)))))
 
 ;;
 ;; Making alist
@@ -689,7 +735,7 @@ the name exists."
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 1997-2003 Mew developing team.
+;; Copyright (C) 1997-2005 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
