@@ -133,6 +133,14 @@
 
 ;;
 
+(defun mew-ssl-cert-directory (&optional case)
+  (mew-cfent-value case "ssl-cert-directory" mew-ssl-cert-directory))
+
+(defun mew-ssl-verify-level (&optional case)
+  (mew-cfent-value case "ssl-verify-level" mew-ssl-verify-level))
+
+;;
+
 (defun mew-smtp-server (&optional case)
   (mew-cfent-value case "smtp-server" mew-smtp-server))
 
@@ -404,7 +412,7 @@
 1. '\\[mew-summary-retrieve]' to select a POP server (or something)
 2. Biff to select a server (or somthing)
 3. If 'mew-use-case-input-completion' is non-nil, this value 
-   is automatically inserted when inputing a folder>")
+   is automatically inserted when inputting a folder>")
 
 (defvar mew-case-output nil
   "This is used to
@@ -548,7 +556,7 @@ fields in the header according to the new value."
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 1999-2003 Mew developing team.
+;; Copyright (C) 1999-2005 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
