@@ -15,7 +15,7 @@
 ;;; Readability
 ;;;
 
-(defconst mew-sp 32)
+(defconst mew-sp ?\ ) ;; 32 does not work on XEmacs
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
@@ -106,8 +106,8 @@
 (defconst mew-ct-apk "Application/Pgp-Keys")
 (defconst mew-ct-pgs "application/pgp-signature") ;; due to the RFC 1847 bug
 (defconst mew-ct-pge "application/pgp-encrypted") ;; due to the RFC 1847 bug
-(defconst mew-ct-sms "application/x-pkcs7-signature")
-(defconst mew-ct-sme "application/x-pkcs7-mime")
+(defconst mew-ct-sms "application/pkcs7-signature")
+(defconst mew-ct-xsms "application/x-pkcs7-signature")
 
 (defconst mew-us-ascii "us-ascii")
 (defconst mew-utf-8 "utf-8")
@@ -324,7 +324,7 @@
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 2000-2003 Mew developing team.
+;; Copyright (C) 2000-2005 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
