@@ -57,7 +57,8 @@
 
 (defvar mew-decode-multipart-signed-switch
   `((,mew-ct-pgs mew-pgp-verify   mew-pgp-ver   mew-prog-pgp)
-    (,mew-ct-sms mew-smime-verify mew-smime-ver mew-prog-smime)))
+    (,mew-ct-sms mew-smime-verify mew-smime-ver mew-prog-smime)
+    (,mew-ct-xsms mew-smime-verify mew-smime-ver mew-prog-smime)))
 
 ;;
 
@@ -602,7 +603,7 @@ Return a part syntax after moving the beginning of the content body."
 	  ;; do nothing
 	  )
 	 (t
-	  ;; xxx how about message/partinal?
+	  ;; xxx how about message/partial?
 	  (mew-syntax-set-ct syntax mew-type-apo)
 	  ))))
      ;; Multipart, decoding is not required
@@ -625,9 +626,6 @@ Return a part syntax after moving the beginning of the content body."
 	    (setq syntax (mew-decode-multipart-encrypted syntax cnt))))
 	 (t
 	  (setq syntax (mew-decode-multipart syntax cnt nil))))))
-     ;; S/MIME encrypted or signed
-     ((string-match mew-ct-sme ct)
-      (setq syntax (mew-smime-decrypt-or-verify syntax cnt ctl cte)))
      ;; Others
      ((string= mew-ct-trh ct)
       (save-restriction
@@ -716,7 +714,7 @@ Return a part syntax after moving the beginning of the content body."
 	(save-excursion
 	  (unless break (forward-line -1))
 	  (beginning-of-line)
-	  (forward-char -1) ;; skip the preceeding CRLF
+	  (forward-char -1) ;; skip the preceding CRLF
 	  ;; the end of the part
 	  (save-restriction
 	    (narrow-to-region start (point))
@@ -902,7 +900,7 @@ Return a part syntax after moving the beginning of the content body."
     ;;
     (delete-region end1 (point-max))
     ;; Now the signed part only
-    ;; Call protocl function
+    ;; Call protocol function
     (cond
      (unknown
       (setq result (concat "unknown protocol " proto)))
@@ -966,7 +964,7 @@ Return a part syntax after moving the beginning of the content body."
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 1996-2003 Mew developing team.
+;; Copyright (C) 1996-2005 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
