@@ -151,6 +151,7 @@ by a header re-write."
 		(let ((mdi (concat (buffer-file-name) mew-draft-info-suffix)))
 		  (mew-delete-file mdi)
 		  (setq msg (mew-smtp-queue case "from Draft mode"))
+		  (mew-remove-buffer buf)
 		  (if (eq action 'send)
 		      (mew-smtp-send-message case queue (list msg))))
 	      (setq err t))))
@@ -200,6 +201,7 @@ by a header re-write."
 		(let ((mdi (concat (buffer-file-name) mew-draft-info-suffix)))
 		  (mew-delete-file mdi)
 		  (setq msg (mew-nntp2-queue case "from Draft mode"))
+		  (mew-remove-buffer buf)
 		  (if (eq action 'send)
 		      (mew-nntp2-send-message  case postq (list msg))))
 	      (setq err t))))
@@ -709,7 +711,7 @@ Note that the message is not a valid MIME message."
   (mew-mark-kill-line)
   (set-buffer-modified-p nil)
   ;; Need to delete Message window because the target message will be
-  ;; modified and its content wiil be changed.
+  ;; modified and its content will be changed.
   (mew-window-configure 'summary)
   (mew-current-set-window-config)
   (mew-window-configure 'draft)
@@ -824,7 +826,7 @@ mew-summary-reedit."
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
-;;; SUb functions
+;;; Sub functions
 ;;;
 
 (defun mew-ct-suffix (ct)
@@ -1008,7 +1010,7 @@ mew-summary-reedit."
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 1999-2003 Mew developing team.
+;; Copyright (C) 1999-2005 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
