@@ -21,12 +21,11 @@
   (cdr (mew-assoc-case-equal cte switch 0)))
 
 (defvar mew-encode-multipart-encrypted-switch
-  '(("application/pgp-encrypted" mew-pgp-encrypt)
-    ("application/x-pkcs7-mime" mew-smime-encrypt)))
+  `((,mew-ct-pge mew-pgp-encrypt)))
 
 (defvar mew-encode-multipart-signed-switch
-  '(("application/pgp-signature" mew-pgp-sign)
-    ("application/x-pkcs7-signature" mew-smime-sign)))
+  `((,mew-ct-pgs mew-pgp-sign)
+    (,mew-ct-sms mew-smime-sign)))
 
 ;;
 
@@ -555,7 +554,7 @@
 	(mew-frwlet
 	 (or cs mew-cs-autoconv) mew-cs-dummy
 	 (mew-insert-file-contents file)))
-      ;; A user may specify charset to convery JIS X 0201 Katakana.
+      ;; A user may specify charset to convey JIS X 0201 Katakana.
       ;; So, we need to avoid the sanity check.
       (unless charset
 	(if mew-use-charset-sanity-check
@@ -891,7 +890,7 @@
       (mew-encode-singlepart 
        (mew-encode-syntax-single file2 (list proto) cte2))
       (insert (format "\n--%s\n" boundary))
-      ;; Insert encrpted body
+      ;; Insert encrypted body
       (mew-encode-singlepart 
        (mew-encode-syntax-single file3 mew-type-apo cte3))
       (insert (format "\n--%s--\n" boundary))
@@ -935,7 +934,7 @@
       (mew-header-insert mew-cte: "7bit")
       (insert (format "\n--%s\n" boundary))
       (goto-char (point-max))
-      ;; After the sigend part
+      ;; After the signed part
       (insert (format "\n--%s\n" boundary))
       (mew-encode-singlepart 
        (mew-encode-syntax-single file2 (or ct2 (list proto)) cte2 nil nil cdp2))
@@ -1107,7 +1106,7 @@
 	(save-excursion
 	  (forward-line -1)
 	  (beginning-of-line) ;; just in case
-	  (forward-char -1) ;; skip the preceeding CRLF
+	  (forward-char -1) ;; skip the preceding CRLF
 	  ;; the end of the part
 	  (save-restriction
 	    (narrow-to-region start (point))
@@ -1180,7 +1179,7 @@
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 1996-2003 Mew developing team.
+;; Copyright (C) 1996-2005 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
