@@ -279,13 +279,7 @@ destination is the same as that of the current message are processed."
 
 (defun mew-summary-go-back-summary (key)
   (let ((msg (mew-summary-message-number))
-	fld)
-    (cond
-     ((mew-thread-p)
-      ;; mew-vinfo-get-parent-folder cannot be used here
-      (setq fld (mew-physical-folder (mew-summary-folder-name 'ext))))
-     ((mew-pickable-p)
-      (setq fld (car (mew-vinfo-get-flds)))))
+	(fld (mew-summary-physical-folder)))
     (if (not (and fld (get-buffer fld)))
 	(message "No physical folder")
       (mew-summary-visit-folder fld nil 'no-ls)
@@ -643,7 +637,7 @@ the queue, type '\\[mew-summary-send-message]' in the queue online."
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 1997-2003 Mew developing team.
+;; Copyright (C) 1997-2005 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
