@@ -110,6 +110,7 @@
 ;;;
 
 (defun mew-attach-external-body ()
+  "Specify external body."
   (interactive)
   (if (not (mew-attach-not-line012-1))
       (message "Cannot insert external-body here")
@@ -420,7 +421,7 @@
      (mew-insert "Server:\t\t%s\n" server)
      (mew-insert "Size:\t%s bytes\n" size)
      (insert "\n")
-     ;; pickd up source from 'mew-send
+     ;; picked up source from 'mew-send
      (mew-insert-manual
       "To send this mail, type "
       "'\\<mew-summary-mode-map>\\[mew-summary-execute-external]'.\n"))))
@@ -524,7 +525,7 @@
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 1996-2003 Mew developing team.
+;; Copyright (C) 1996-2005 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
