@@ -424,7 +424,7 @@ Remove anonymous addresses."
 (defun mew-addrstr-extract-user (addr)
   "Extracts username from ADDR"
   (if (string-match "@.*:" addr) ;; xxx what's this?
-      (setq addr (substring addr (match-end 0) nil))
+      (setq addr (substring addr (match-end 0)))
     (setq addr (mew-replace-character addr mew-sp ?_))
     (setq addr (substring addr 0 (string-match "%" addr)))
     (setq addr (substring addr 0 (string-match "@" addr)))
@@ -484,7 +484,7 @@ Remove anonymous addresses."
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 1996-2003 Mew developing team.
+;; Copyright (C) 1996-2005 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
