@@ -77,6 +77,7 @@
   (define-key mew-summary-mode-map "p"    'mew-summary-display-up)
   (define-key mew-summary-mode-map "\C-n" 'mew-summary-next-line)
   (define-key mew-summary-mode-map "\C-p" 'mew-summary-previous-line)
+  (define-key mew-summary-mode-map "e"    'mew-summary-exchange-marks)
   (define-key mew-summary-mode-map "M"	  (make-sparse-keymap))
   (define-key mew-summary-mode-map "Md"   'mew-summary-mark-duplicated)
   (define-key mew-summary-mode-map "M*"   'mew-summary-redo)
@@ -84,7 +85,7 @@
   (define-key mew-summary-mode-map "P"    'mew-summary-display-review-up)
   (define-key mew-summary-mode-map "\en"  'mew-summary-find-keyword-down)
   (define-key mew-summary-mode-map "\ep"  'mew-summary-find-keyword-up)
-  (define-key mew-summary-mode-map "w"    'mew-summary-send)
+  (define-key mew-summary-mode-map "w"    'mew-summary-write)
   (define-key mew-summary-mode-map "W"    'mew-summary-send-to-others)
   (define-key mew-summary-mode-map "B"    'mew-summary-burst)
   (define-key mew-summary-mode-map "K"    'mew-summary-old-burst)
@@ -170,12 +171,28 @@
   (define-key mew-summary-mode-map "zo"   'mew-summary-toggle-pgp)
   (define-key mew-summary-mode-map "zv"   'mew-summary-toggle-header-veil)
   (define-key mew-summary-mode-map "zw"   'mew-summary-toggle-warning)
+  (define-key mew-summary-mode-map "zi"   'mew-summary-toggle-invisible)
   (define-key mew-summary-mode-map "z "   'mew-summary-toggle-mark-regex)
   (define-key mew-summary-mode-map "l"	  (make-sparse-keymap))
   (define-key mew-summary-mode-map "lc"   'mew-summary-local-copy)
   (define-key mew-summary-mode-map "lh"   'mew-summary-learn-ham)
   (define-key mew-summary-mode-map "ls"   'mew-summary-learn-spam)
   (define-key mew-summary-mode-map "="    'mew-summary-info)
+  (define-key mew-summary-mode-map "k"	  (make-sparse-keymap))
+  (define-key mew-summary-mode-map "k?"   'mew-nmz-search-mark)
+  (define-key mew-summary-mode-map "k/"   'mew-nmz-virtual)
+  (define-key mew-summary-mode-map "kV"   'mew-nmz-virtual)
+  (define-key mew-summary-mode-map "kg"   'mew-nmz-gcnmz)
+  (define-key mew-summary-mode-map "km"   'mew-nmz-mknmz)
+  (define-key mew-summary-mode-map "kM"   'mew-nmz-mknmz-all-folders)
+  (define-key mew-summary-mode-map "ks"   'mew-nmz-mknmz-save-mewmknmz)
+  (define-key mew-summary-mode-map "kK"   'mew-nmz-mknmz-kill-process)
+  (define-key mew-summary-mode-map "ku"   'mew-nmz-mark-unindexed)
+  (define-key mew-summary-mode-map "k^"   'mew-nmz-search-parent)
+  (define-key mew-summary-mode-map "kp"   'mew-nmz-search-parent)
+  (define-key mew-summary-mode-map "kn"   'mew-nmz-search-child)
+  (define-key mew-summary-mode-map "kN"   'mew-nmz-namazu)
+  (define-key mew-summary-mode-map "kj"   'mew-nmz-original-message)
   ;;
   ;; not provided in Virtual mode
   ;;
@@ -287,10 +304,13 @@
   (define-key mew-message-mode-map "a"    'mew-message-reply)
   (define-key mew-message-mode-map "A"    'mew-message-reply-with-citation)
   (define-key mew-message-mode-map "f"    'mew-message-forward)
-  (define-key mew-message-mode-map "r"    'mew-message-resend))
+  (define-key mew-message-mode-map "r"    'mew-message-resend)
+  (define-key mew-message-mode-map "k"	  (make-sparse-keymap))
+  (define-key mew-message-mode-map "kp"   'mew-nmz-search-msgid-at-point)
+  (define-key mew-message-mode-map "kr"   'mew-nmz-search-msgid-region))
 
 (defvar mew-message-mode-menu-spec
-  '("Mew/message"
+  '("Mew"
     ["Next part"    mew-message-next-msg     t]
     ["Prev part"    mew-message-prev-msg     t]
     ["Next page"    mew-message-next-page    t]
@@ -309,10 +329,10 @@
   (define-key (symbol-value symmap) "\C-c\C-a" 'mew-draft-prepare-attachments)
   (define-key (symbol-value symmap) "\C-c\C-l" 'mew-draft-rehighlight)
   (define-key (symbol-value symmap) "\C-c\C-q" 'mew-draft-kill)
-  (define-key (symbol-value symmap) "\C-c\C-s" 'mew-pgp-sign-message)
-  (define-key (symbol-value symmap) "\C-c\C-e" 'mew-pgp-encrypt-message)
-  (define-key (symbol-value symmap) "\C-c\C-b" 'mew-pgp-sign-encrypt-message)
-  (define-key (symbol-value symmap) "\C-c\C-r" 'mew-pgp-encrypt-sign-message)
+  (define-key (symbol-value symmap) "\C-c\C-s" 'mew-draft-sign-message)
+  (define-key (symbol-value symmap) "\C-c\C-e" 'mew-draft-encrypt-message)
+  (define-key (symbol-value symmap) "\C-c\C-b" 'mew-draft-sign-encrypt-message)
+  (define-key (symbol-value symmap) "\C-c\C-r" 'mew-draft-encrypt-sign-message)
   (define-key (symbol-value symmap) "\C-c\C-p\C-a"
     'mew-draft-toggle-privacy-always)
   (define-key (symbol-value symmap) "\C-c\C-p\C-e"
@@ -405,7 +425,7 @@
 
 (defvar mew-draft-mode-menu-spec
   (list  ;; need to eval mew-draft-mode-toolbar-menu
-   "Mew/Draft"
+   "Mew"
    ["Cite"                mew-draft-cite t]
    ["Cite without Label"  mew-draft-yank t]
    mew-draft-mode-toolbar-menu
@@ -449,7 +469,7 @@
   (define-key mew-header-mode-map "\C-c\C-o" 'mew-draft-set-case))
 
 (defvar mew-header-mode-menu-spec
-  '("Mew/Header"
+  '("Mew"
     ["Queue Message"   mew-header-make-message t]
     ["Send Message"    mew-header-send-message t]
     ["Set cases"       mew-draft-set-case      t]
@@ -487,6 +507,7 @@
   (define-key mew-draft-attach-map "Q"      'mew-attach-quoted-printable)
   (define-key mew-draft-attach-map "S"      'mew-attach-pgp-sign)
   (define-key mew-draft-attach-map "E"      'mew-attach-pgp-enc)
+  (define-key mew-draft-attach-map "\es"    'mew-attach-smime-sign)
   (define-key mew-draft-attach-map "p"      'mew-attach-pgp-public-key)
   (define-key mew-draft-attach-map "U"      'mew-attach-undo)
   (define-key mew-draft-attach-map "\C-c\t" 'mew-draft-insert-signature)
@@ -521,7 +542,15 @@
   (define-key mew-input-map "\t"     'mew-input-complete)
   (define-key mew-input-map [tab]    'mew-input-complete)
   (define-key mew-input-map "?"      'mew-input-complete)
-  (define-key mew-input-map "\C-c\t" 'mew-circular-complete-switch))
+  (define-key mew-input-map "\C-c\t" 'mew-circular-complete-switch)
+  (define-key mew-input-map [menu-bar minibuf]
+    (cons "Mew" (make-sparse-keymap "Mew")))
+  (define-key mew-input-map [menu-bar minibuf quit]
+    (list 'menu-item "Quit" 'keyboard-escape-quit
+          :help "Abort input and exit minibuffer"))
+  (define-key mew-input-map [menu-bar minibuf return]
+    (list 'menu-item "Enter" 'exit-minibuffer
+          :help "Terminate input and exit minibuffer")))
 
 (unless mew-input-folder-map
   (setq mew-input-folder-map (copy-keymap mew-input-map))
@@ -587,8 +616,16 @@
 ;;; Icons
 ;;;
 
-(defvar mew-icon-directory (if (fboundp 'locate-data-directory)
-			       (locate-data-directory "mew") nil))
+(defun mew-which-mew-etc ()
+  (let ((file "mew.el")
+	(path load-path))
+    (catch 'loop
+      (while path
+	(if (file-exists-p (expand-file-name file (car path)))
+	    (throw 'loop (expand-file-name "etc" (car path)))
+	  (setq path (cdr path)))))))
+
+(defvar mew-icon-directory (mew-which-mew-etc))
 
 (defvar mew-icon-separate nil)
 (defvar mew-icon-blank nil)
@@ -621,7 +658,7 @@
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 2000-2003 Mew developing team.
+;; Copyright (C) 2000-2005 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
