@@ -16,7 +16,8 @@
   "Delete refile state and delete the mark."
   (mew-summary-refile-remove-body)
   (unless (mew-virtual-p)
-    (mew-refile-reset msg)))
+    (mew-refile-reset msg)
+    (mew-summary-refile-unlog fld)))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
@@ -59,8 +60,7 @@
   "Cancel all marks according to what you input."
   (interactive)
   (let ((char (mew-input-mark)))
-    (if (and char (not (char-equal char ?\r)))
-	(mew-mark-undo-mark char))))
+    (if char (mew-mark-undo-mark char))))
 
 (defun mew-mark-undo-mark (mark &optional no-msg virtual-only)
   "Undo MARK on the entire buffer.
@@ -105,6 +105,7 @@ If optional argument NO-MSG is non-nil, no message is displayed."
 ;;
 
 (defun mew-summary-redo ()
+  "\\<mew-summary-mode-map>Recover the `*' marks which are canceled by the last `\\[mew-summary-undo-all]*'."
   (interactive)
   (let ((mark mew-mark-review)
 	(reviews (mew-sinfo-get-mark-review))
@@ -222,7 +223,21 @@ cons pairs of folder name and message number."
 	(forward-line))
       (nreverse ret))))
 
-(defun mew-summary-mark-recover (mdb &optional ref)
+(defun mew-summary-mark-collect5 ()
+  (save-excursion
+    (let ((beg (mew-net-invalid-cache-start))
+	  ret mrk msg)
+      (when beg
+	(goto-char beg)
+	(while (re-search-forward mew-regex-mark nil t)
+	  (setq mrk (mew-sumsyn-mark))
+	  (setq msg (mew-summary-message-number))
+	  (setq msg (int-to-string (string-to-int msg)))
+	  (setq ret (cons (list msg mrk) ret))
+	  (forward-line))
+	(nreverse ret)))))
+
+(defun mew-summary-mark-recover (mdb &optional refdb refs)
   (let ((opos (point))
 	ent msg mrk new-ref ref-ent)
     (goto-char (point-min))
@@ -231,12 +246,16 @@ cons pairs of folder name and message number."
       (setq mdb (cdr mdb))
       (mew-set '(msg mrk) ent)
       (when (re-search-forward (mew-regex-sumsyn-msg msg) nil t)
-	(if (or (not (char-equal mrk mew-mark-refile)) (null ref))
+	(if (or (not (char-equal mrk mew-mark-refile)) (null refdb))
 	    (mew-mark-put mrk)
-	  (when (setq ref-ent (assoc msg ref))
+	  (when (setq ref-ent (assoc msg refdb))
 	    (mew-mark-put mrk)
 	    (setq new-ref (cons ref-ent new-ref))))
 	(forward-line)))
+    (while refs
+      (when (setq ref-ent (assoc (car refs) refdb))
+	(setq new-ref (cons ref-ent new-ref)))
+      (setq refs (cdr refs)))
     (goto-char opos)
     (nreverse new-ref)))
 
@@ -777,7 +796,9 @@ region."
 ;;;
 
 (defun mew-summary-set-walk-mark ()
-  (let ((char (mew-input-mark)))
+  (let* ((msg (format "Input mark(%c): " mew-mark-default-walk))
+	 (mew-mark-spec (cons (list 13) mew-mark-spec)) ;; adding \r
+	 (char (mew-input-mark msg)))
     (cond
      ((null char)
       ;; mew-input-mark displays a message.
@@ -785,7 +806,9 @@ region."
      ((char-equal char ?\r)
       (setq mew-mark-walk mew-mark-default-walk)
       (message "Target mark was set to '%c'" mew-mark-walk))
-     (char (setq mew-mark-walk char)))))
+     (char
+      (setq mew-mark-walk char)
+      (message "Target mark was set to '%c'" mew-mark-walk)))))
 
 (defun mew-summary-down-mark (mark)
   (let ((case-fold-search nil))
@@ -830,6 +853,42 @@ the specified mark."
     (if (mew-summary-up-mark mew-mark-walk)
 	(mew-summary-display nil))))
 
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;;;
+;;; Mark exchange
+;;;
+
+(defun mew-summary-input-exchangeable-mark (msg)
+  (let (mark)
+    (catch 'loop
+      (while t
+	(setq mark (mew-input-mark msg))
+	(cond
+	 ((null mark)
+	  (message "That is not a mark")
+	  (mew-let-user-read))
+	 ((mew-markdb-statefullp mark)
+	  (message "'%c' cannot be exchanged" mark)
+	  (mew-let-user-read))
+	 (t
+	  (throw 'loop mark)))))))
+
+(defun mew-summary-exchange-marks ()
+  "Exchange the first input mark to the second one.
+The 'o' mark is not exchangeable."
+  (interactive)
+  (let* ((from (mew-summary-input-exchangeable-mark "Input mark from: "))
+	 (to  (mew-summary-input-exchangeable-mark "Input mark to: "))
+	 (regex (mew-mark-regex from))
+	 (case-fold-search nil))
+    (unless (char-equal from to)
+      (save-excursion
+	(goto-char (point-min))
+	(while (re-search-forward regex nil t)
+	  (mew-summary-undo-one 'nomsg)
+	  (mew-mark-put-mark to 'nomsg))
+	(forward-line)))))
+
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
 ;;; Clean up marks!
@@ -856,7 +915,7 @@ the specified mark."
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 1997-2003 Mew developing team.
+;; Copyright (C) 1997-2005 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
