@@ -146,7 +146,7 @@
 	(mew-message-narrow-to-page)))))
 
 (defun mew-mime-text/plain-ext (cache begin end &optional params)
-  "To call the Text/Plian function for a text attachment whose
+  "To call the Text/Plain function for a text attachment whose
 Content-Type: is Application/Octet-Stream."
   ;; called in Message buffer
   (when (> end begin)
@@ -576,6 +576,10 @@ Content-Type: is Application/Octet-Stream."
   (mew-mime-application/msoffice
    mew-prog-application/mspowerpoint cache begin end parameter))
 
+(defun mew-mime-application/rtf (cache begin end &optional parameter)
+  (mew-mime-application/msoffice
+   mew-prog-application/rtf cache begin end parameter))
+
 (defun mew-mime-application/msword-ext (cache begin end &optional parameter)
   (save-excursion
     (mew-erase-buffer)
@@ -591,6 +595,11 @@ Content-Type: is Application/Octet-Stream."
     (mew-erase-buffer)
     (mew-mime-application/mspowerpoint cache begin end parameter)))
 
+(defun mew-mime-application/rtf-ext (cache begin end &optional parameter)
+  (save-excursion
+    (mew-erase-buffer)
+    (mew-mime-application/rtf cache begin end parameter)))
+
 (defun mew-mime-application/msoffice (prog cache begin end &optional parameter)
   (let ((doit t) file1 file2)
     (unless mew-internal-utf-8p
@@ -630,9 +639,13 @@ Content-Type: is Application/Octet-Stream."
 			   (file-name-nondirectory file2)))
 	   (let ((buffer-file-coding-system)) ;; to prevent the side effect
 	     (mew-insert-file-contents file2)))
-	(mew-frwlet
-	 'utf-8 mew-cs-dummy
-	 (call-process prog nil (current-buffer) nil file1)))
+	(if (eq prog mew-prog-application/rtf)
+	    (mew-frwlet
+	     'shift_jis mew-cs-dummy
+	     (call-process prog nil (current-buffer) nil file1))
+	  (mew-frwlet
+	   'utf-8 mew-cs-dummy
+	   (call-process prog nil (current-buffer) nil file1))))
       (mew-delete-file file1)
       (mew-delete-file file2)
       (save-excursion
@@ -679,7 +692,7 @@ Content-Type: is Application/Octet-Stream."
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 1997-2003 Mew developing team.
+;; Copyright (C) 1997-2005 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
