@@ -460,7 +460,7 @@ it is deleted automatically."
        ;;
        ((save-excursion
 	  (forward-char -2)
-	  (looking-at ":[-+*%$]"))
+	  (looking-at ":[-+%$*]"))
 	(forward-char -1)
 	(delete-char 1)
 	(when (memq last-command-char '(?+ ?*))
@@ -501,6 +501,7 @@ it is deleted automatically."
 	  (throw 'continue nil))
 	(setq case:folder (mew-canonicalize-case-folder case:folder))
 	(setq ret (cons case:folder ret))))
+    (setq ret (delete nil ret))
     (nreverse ret)))
 
 (defun mew-input-local-folder (folder)
@@ -842,9 +843,9 @@ it is deleted automatically."
 
 (defun mew-convert-to-home-dir (dir)
   (let* ((chome (file-name-as-directory mew-home))
-	 (ehome (expand-file-name chome)))
+	 (ehome (concat "^" (regexp-quote (expand-file-name chome)))))
     (if (string-match ehome dir)
-	(concat chome (substring dir (match-end 0) nil))
+	(concat chome (substring dir (match-end 0)))
       dir)))
 
 (defvar mew-summary-previous-directory nil)
@@ -978,18 +979,17 @@ it is deleted automatically."
 ;;; Mark
 ;;;
 
-(defun mew-input-mark ()
+(defun mew-input-mark (&optional msg)
   (let ((ociea cursor-in-echo-area) char)
     (unwind-protect
 	(progn
-	  (message "Input mark: ")
+	  (message (or msg "Input mark: "))
 	  (setq cursor-in-echo-area t)
 	  (setq char (read-char))
 	  (unless (char-equal char ?\r)
-	    (message "Input mark: %c" char)))
+	    (message "%s%c" (or msg "Input mark: ") char)))
       (setq cursor-in-echo-area ociea))
     (cond
-     ((char-equal char ?\r) char)
      ((mew-markdb-by-mark char) char)
      (t (message "Mark %c is not supported" char)
 	nil))))
@@ -1089,7 +1089,7 @@ it is deleted automatically."
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 1997-2003 Mew developing team.
+;; Copyright (C) 1997-2005 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
