@@ -47,6 +47,11 @@
 (defvar mew-cs-autoconv       'undecided)
 ;; ctext for consistency --unibyte, -unix for XEmacs's ^M
 (defvar mew-cs-m17n (if (mew-coding-system-p 'ctext-unix) 'ctext-unix 'ctext))
+(defvar mew-cs-utf-16be
+  (cond
+   ((mew-coding-system-p 'utf-16-be-no-signature) 'utf-16-be-no-signature)
+   ((mew-coding-system-p 'utf-16be) 'utf-16be)
+   (t nil)))
 
 (defvar mew-cs-eol "\n")
 (defun mew-eol-fix-for-read () ())
@@ -194,7 +199,7 @@
 (defun mew-cs-decode-region (beg end cs)
   (if cs (decode-coding-region beg end cs)))
 
-;; to extenal
+;; to external
 (defun mew-cs-encode-region (beg end cs)
   (if cs (encode-coding-region beg end cs)))
 
@@ -210,7 +215,7 @@
       (if (null post-conv)
 	  (decode-coding-string str cs)
 	;; Mule 4.1 (Emacs 20.7 + Mule-UCS-0.84) has a bug.
-	;; It applys post-conv just to a buffer, not to a string.
+	;; It applies post-conv just to a buffer, not to a string.
 	;; So, we should use a buffer.
 	(with-temp-buffer
 	  ;; The old base64-decode-string() returns a multibyte string.
@@ -366,7 +371,7 @@
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 1997-2003 Mew developing team.
+;; Copyright (C) 1997-2005 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
