@@ -22,7 +22,8 @@
     ("nntp"  . "119")
     ("nntps" . "563")
     ("imap"  . "143")
-    ("imaps" . "993")))
+    ("imaps" . "993")
+    ("submission" . "587")))
 
 (defun mew-serv-to-port (serv)
   (if (string-match "^[0-9]+$" serv)
@@ -129,6 +130,8 @@
     (set-buffer buf)
     (mew-elet (put-text-property (point-min) (point-max) 'invisible nil))
     (setq mew-summary-buffer-raw t)
+    (if (eq (get-buffer-window buf) (selected-window))
+	(mew-summary-cook-window))
     (set-buffer-modified-p nil)))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
@@ -404,21 +407,26 @@
     (setq mew-summary-buffer-raw nil)
     (mew-summary-folder-cache-save)))
 
+(defun mew-net-invalid-cache-start ()
+  (save-excursion
+    (goto-char (point-min))
+    (when (re-search-forward mew-regex-sumsyn-invalid nil t)
+      (beginning-of-line)
+      (point))))
+
+(defun mew-net-invalid-cache-invisible ()
+  (let ((beg (mew-net-invalid-cache-start)))
+    (when beg
+      (mew-elet
+       (put-text-property beg (point-max) 'invisible t)))))
+
 (defun mew-net-invalid-cache-clean ()
   (let* ((bnm (mew-summary-folder-name 'ext))
 	 (dir (mew-expand-folder bnm))
-	 (msgs (mew-dir-messages dir mew-regex-message-files4))
-	 beg)
-    (save-excursion
-      (goto-char (point-min))
-      (when (re-search-forward mew-regex-sumsyn-invalid nil t)
-	(beginning-of-line)
-	(setq beg (point))
-	(goto-char (point-max))
-	(mew-elet
-	 (delete-region beg (point)))
-	(mew-summary-unlink-msgs bnm msgs)
-	(mew-summary-folder-cache-save)))))
+	 (msgs (mew-dir-messages dir mew-regex-message-files4)))
+    (mew-summary-unlink-msgs bnm msgs)
+    (mew-mark-kill-invisible)
+    (mew-summary-folder-cache-save)))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
@@ -507,13 +515,18 @@ If called with '\\[universal-argument]', +queue is not flushed."
 
 (defun mew-mbox-retrieve (case directive inbox &optional flush)
   ;; directive is 'inc
-  (let ((mbox-command (mew-mbox-command case))
-	(mbox-command-arg (mew-mbox-command-arg case))
-	opts)
+  (let* ((mbox-command (mew-mbox-command case))
+	 (mbox-command-arg (mew-mbox-command-arg case))
+	 dir mode opts)
     (if (not (mew-which-exec mbox-command))
 	(message "'%s' not found!" mbox-command)
       (if mbox-command-arg
-	  (setq opts (list "-e" mbox-command "-m" mbox-command-arg))
+	  (if (not (string= mbox-command "incm"))
+	      (setq opts (list "-e" mbox-command "-m" mbox-command-arg))
+	    (setq dir (mew-expand-folder inbox))
+	    (setq mode (mew-get-file-modes dir))
+	    (setq opts (list "-e" mbox-command
+			     "-m" (format "%s -p %d" mbox-command-arg mode))))
 	(setq opts (list "-e" mbox-command)))
       (mew-local-retrieve 'inc inbox flush opts))))
 
@@ -690,7 +703,7 @@ The messages in the server side is always retained."
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 2002-2003 Mew developing team.
+;; Copyright (C) 2002-2005 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
