@@ -419,7 +419,7 @@
 	 (pnm (mew-nntp-info-name case newsgroup))
 	 (buf (get-buffer-create (mew-nntp-buffer-name pnm)))
 	 (no-msg (eq directive 'biff))
-	 process sshname sshpro sslname sslpro lport)
+	 process sshname sshpro sslname sslpro lport tls)
     (if (mew-nntp-get-process pnm)
 	(message "Another NNTP process is running. Try later")
       (cond
@@ -431,7 +431,8 @@
 	  (when lport
 	    (setq process (mew-nntp-open pnm "localhost" lport no-msg)))))
        (sslp
-	(setq sslpro (mew-open-ssl-stream server sslport))
+	(if (string= port sslport) (setq tls mew-tls-nntp))
+	(setq sslpro (mew-open-ssl-stream case server sslport tls))
 	(when sslpro
 	  (setq sslname (process-name sslpro))
 	  (setq lport (mew-ssl-pnm-to-lport sslname))
@@ -575,7 +576,7 @@
 	    (when recovered
 	      (mew-nntp-message
 	       pnm
-	       "%d message retrieved. %d messages are left due to an error."
+	       "%d message retrieved. %d messages are left due to an error"
 	       (- rttl lefts) lefts)
 	      (mew-summary-folder-cache-save))))
       (cond
@@ -683,7 +684,7 @@
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 1999-2003 Mew developing team.
+;; Copyright (C) 1999-2005 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
