@@ -109,15 +109,12 @@
   (let ((fcc (mew-nntp2-get-fcc pnm))
 	(case (mew-nntp2-get-case pnm))
 	(back (mew-queue-backup (buffer-file-name) mew-queue-info-suffix))
-	(buf (process-buffer pro))
 	imapp)
     ;; mew-folder-new-message may be slow if the folder contains
     ;; a lot of messages. So, let's Fcc in background.
     (setq imapp (mew-net-fcc-message case fcc back))
     (mew-nntp2-set-imapp pnm imapp)
     (mew-nntp2-log pnm)
-    (set-process-buffer pro nil)
-    (mew-remove-buffer buf)
     (mew-nntp2-set-status pro "next")
     (mew-nntp2-command-next pro pnm)))
 
@@ -216,7 +213,7 @@
 	(sshsrv (mew-nntp-ssh-server case))
 	(sslp (mew-nntp-ssl case))
 	(sslport (mew-nntp-ssl-port case))
-	process sshname sshpro sslname sslpro lport)
+	process sshname sshpro sslname sslpro lport tls)
     (cond
      (sshsrv
       (setq sshpro (mew-open-ssh-stream case server port sshsrv))
@@ -226,7 +223,8 @@
 	(when lport
 	  (setq process (mew-nntp2-open pnm "localhost" lport)))))
      (sslp
-      (setq sslpro (mew-open-ssl-stream server sslport))
+      (if (string= port sslport) (setq tls mew-tls-nntp))
+      (setq sslpro (mew-open-ssl-stream case server sslport tls))
       (when sslpro
 	(setq sslname (process-name sslpro))
 	(setq lport (mew-ssl-pnm-to-lport sslname))
@@ -239,7 +237,7 @@
 	 ((and sshsrv (null sshpro))
 	  (message "Cannot create to the SSH connection"))
 	 ((and sslp (null sslpro))
-	  (message "Cannot create to the SSL connection"))
+	  (message "Cannot create to the SSL/TLS connection"))
 	 (t
 	  (message "Cannot connect to the NNTP server")))
       (mew-info-clean-up pnm mew-nntp2-info-list-clean-length)
@@ -263,12 +261,14 @@
 (defun mew-nntp2-flush-queue (case &optional qfld)
   (let (msgs)
     (unless qfld (setq qfld (mew-postq-folder case)))
-    (setq msgs (mew-folder-messages qfld))
-    (when msgs
-      (mew-summary-folder-cache-clean qfld)
-      (run-hooks 'mew-nntp2-flush-hook)
-      (message "Flushing %s..." qfld)
-      (mew-nntp2-send-message case qfld msgs))))
+    (if (mew-nntp2-get-server (mew-nntp2-info-name case)) ;; lock
+	(message "%s is locked" qfld)
+      (setq msgs (mew-folder-messages qfld))
+      (when msgs
+	(mew-summary-folder-cache-clean qfld)
+	(run-hooks 'mew-nntp2-flush-hook)
+	(message "Flushing %s..." qfld)
+	(mew-nntp2-send-message case qfld msgs)))))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
@@ -284,7 +284,6 @@
 
 (defun mew-nntp2-filter (process string)
   (let* ((pnm (process-name process))
-	 (case (mew-nntp2-get-case pnm))
 	 (status (mew-nntp2-get-status pnm))
 	 (str (concat (mew-nntp2-get-string pnm) string))
 	 (buf (process-buffer process))
@@ -308,14 +307,9 @@
 	(if (string-match "^pwd-" status)
 	    (mew-nntp2-set-error pnm "NNTP password is wrong!")
  	  (if (string-match "\n$" str)
- 	      (setq str (substring str 0 (1- (length str)))))
+ 	      (setq str (substring str 0 -1)))
  	  (unless (string-match "[.!]$" str)
  	    (setq str (concat str "."))))
-	(if (null buf)
-	    ;; A message file is not inserted at the beginning of the NNTP
-	    ;; session.
-	    ()
-	  (mew-nntp2-queue case str))
 	(mew-nntp2-set-error pnm str)
 	(mew-nntp2-command-quit2 process pnm))))
      (t ())))) ;; stay
@@ -334,6 +328,11 @@
     (cond
      (error
       (message "%s  This mail has been queued to %s" error qfld)
+      (when buf
+	;; A message file is not inserted at the beginning of the NNTP
+	;; session.
+	(set-buffer buf)
+	(mew-nntp2-queue case error))
       (mew-nntp2-log pnm error))
      (done
       (message "Posting in background...done"))
@@ -348,7 +347,8 @@
     (if (and (processp sslpro) (not mew-ssl-keep-connection))
 	(delete-process sslpro))
     (run-hooks 'mew-nntp2-sentinel-hook)
-    (if imapp (mew-imap2-fcc case))))
+    (if imapp (mew-imap2-fcc case))
+    (when buf (mew-remove-buffer buf))))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
@@ -400,7 +400,7 @@
       (and msgid (insert " id=" msgid))
       (and server (insert " server=" server))
       (and sshsrv (insert " sshsrv=" sshsrv))
-      (and sslp (insert " SSL"))
+      (and sslp (insert " SSL/TLS"))
       (and newsgroups (insert " newsgroups=" newsgroups))
       (if err
 	  (insert " status=" "("
@@ -416,7 +416,7 @@
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 1999-2003 Mew developing team.
+;; Copyright (C) 1999-2005 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
