@@ -186,12 +186,15 @@ Set 1 if 5. Set 2 if 6. Set 3 if GNUPG.")
 (defvar mew-pgp-micalg '("pgp-md5" "pgp-sha1" "pgp-sha1" "pgp-sha1"))
 
 (defvar mew-pgp-hash-alist
-  '(("1" . "pgp-md5")
-    ("2" . "pgp-sha1")
-    ("3" . "pgp-ripemd160")
-    ("5" . "pgp-md2")
-    ("6" . "pgp-tiger192")
-    ("7" . "pgp-haval-5-160")))
+  '(("1"  . "pgp-md5")
+    ("2"  . "pgp-sha1")
+    ("3"  . "pgp-ripemd160")
+    ("5"  . "pgp-md2")
+    ("6"  . "pgp-tiger192")
+    ("7"  . "pgp-haval-5-160")
+    ("8"  . "pgp-sha256")
+    ("9"  . "pgp-sha384")
+    ("10" . "pgp-sha512")))
 
 ;;
 ;;
@@ -533,7 +536,7 @@ Set 1 if 5. Set 2 if 6. Set 3 if GNUPG.")
        ;; decrypt-then-verify
        ((eq mew-pgp-failure mew-pgp-err-pubring)
 	(setq msg decrypted))
-       ;; decrypt-then-vrify
+       ;; decrypt-then-verify
        ((eq mew-pgp-failure mew-pgp-err-pubkey)
 	(setq msg decrypted))
        ;; sign
@@ -627,7 +630,7 @@ Set 1 if 5. Set 2 if 6. Set 3 if GNUPG.")
     (process-send-string process "\n")
     (set-process-filter process 'mew-pgp-process-filter3))
 
-   ;; after decrypted secret key, symmetric key is not uknown...
+   ;; after decrypted secret key, symmetric key is not unknown...
    ;; gpg: unknown cipher algorithm
    ;; no secret key or no secring for decrypt
    ((string-match (mew-pgp-get mew-pgp-msg-no-seckey-or-secring) string)
@@ -684,7 +687,7 @@ Set 1 if 5. Set 2 if 6. Set 3 if GNUPG.")
   (interactive "P")
   (mew-pgp-encode-message 'pgp-encryption-signature))
 
-(defsubst mew-pgp-encode-message (type &optional ask-singer)
+(defun mew-pgp-encode-message (type &optional ask-singer)
   (if (null mew-pgp-ver)
       (message "%s does not exist" mew-prog-pgp)
     (let ((func 'mew-draft-make-message))
@@ -731,8 +734,8 @@ Set 1 if 5. Set 2 if 6. Set 3 if GNUPG.")
 		    (setq cs (mew-charset-to-cs charset))
 		    (setq doit t)
 		    (mew-attach-clear))
-		(message "Old PGP cannot be used for non-text.")))
-	  (message "Old PGP cannot be used if multipart exists."))
+		(message "Old PGP cannot be used for non-text")))
+	  (message "Old PGP cannot be used if multipart exists"))
       (setq doit t))
     (when doit
       (setq mew-inherit-encode-signer (or signer (mew-get-my-address)))
@@ -744,7 +747,7 @@ Set 1 if 5. Set 2 if 6. Set 3 if GNUPG.")
        ((eq type 'pgp-signature-encryption)
 	(mew-pgp-old-sign-encrypt cs))
        (t
-	(message "Not supported."))))))
+	(message "Not supported"))))))
 
 (defun mew-old-pgp-sign (cs &optional syntax)
   (let ((file1 (mew-make-temp-name))
@@ -997,7 +1000,7 @@ Set 1 if 5. Set 2 if 6. Set 3 if GNUPG.")
 ;;;
 
 (defun mew-attach-pgp-public-key ()
-  "Extract the PGP key for the inputed user on '.'. in attachments"
+  "Extract the PGP key for the inputted user on '.'. in attachments"
   (interactive)
   (if (not (mew-attach-not-line012-1))
       (message "Cannot link here")
@@ -1130,7 +1133,7 @@ public keyring."
 (defun mew-pgp-fetch-key (arg)
   "Fetch a PGP public key. 
 
-A PGP public key is fetch from one of the PGP PKS servers wich a
+A PGP public key is fetch from one of the PGP PKS servers with a
 key ID which is extracted from the X-Mew: field. The list of the
 PGP PKS servers is specified by 'mew-pgp-pks-servers'.
 
@@ -1162,7 +1165,7 @@ according to a URL in a field specified by 'mew-x-pgp-key-list'."
 	 uri)
     (unless id
       (setq id (read-string "PGP key id or e-mail address: ")))
-    (setq server (completing-read "PGP ker server: " alist nil nil server))
+    (setq server (completing-read "PGP key server: " alist nil nil server))
     (unless (mew-pgp-pks-http-port-p server alist)
       (setq server (concat server ":" mew-pgp-pks-port)))
     (setq uri (concat "http://" server mew-pgp-pks-lang id))
@@ -1230,7 +1233,7 @@ according to a URL in a field specified by 'mew-x-pgp-key-list'."
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 1994-2003 Mew developing team.
+;; Copyright (C) 1994-2005 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
