@@ -205,7 +205,7 @@ the region."
 	 (default-directory dir) ;; buffer local
 	 msgs nxt)
     ;; no sort here
-    (if (= (length src-msgs) 1) (setq src-msgs (cons "/dev/null" src-msgs)))
+    (if (= (length src-msgs) 1) (setq src-msgs (cons null-device src-msgs)))
     (setq pattern (mew-cs-encode-arg pattern))
     (with-temp-buffer
       (cd dir)
@@ -242,7 +242,7 @@ the region."
 	 (cmd mew-inherit-grep-cmd)
 	 msgs nxt arg)
     ;; no sort here
-    (if (= (length src-msgs) 1) (setq src-msgs (cons "/dev/null" src-msgs)))
+    (if (= (length src-msgs) 1) (setq src-msgs (cons null-device src-msgs)))
     (with-temp-buffer
       (cd dir)
       (mew-piolet
@@ -471,7 +471,7 @@ keyword, execute this command with '\\[universal-argument]'."
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 1996-2003 Mew developing team.
+;; Copyright (C) 1996-2005 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
