@@ -13,7 +13,7 @@
   mew-pop-folder-alist)
 
 ;; It is impossible to implement mew-pop-skip-uidl since
-;; messages cannot be gaind access by UID.
+;; messages cannot be gained access by UID.
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
@@ -42,6 +42,8 @@
     ("capa"          t   ("\\+OK" . "auth") ("-ERR" . "pswd"))
     ("auth-cram-md5" nil ("\\+OK" . "pwd-cram-md5") ("-ERR" . "wpwd"))
     ("pwd-cram-md5"  nil ("\\+OK" . "list") ("-ERR" . "wpwd"))
+    ("auth-plain"    nil ("\\+OK" . "pwd-plain") ("-ERR" . "wpwd"))
+    ("pwd-plain"     nil ("\\+OK" . "list") ("-ERR" . "wpwd"))
     ("apop"          nil ("\\+OK" . "list") ("-ERR" . "wpwd"))
     ("user"          nil ("\\+OK" . "pass") ("-ERR" . "wpwd2"))
     ("pass"          nil ("\\+OK" . "list") ("-ERR" . "wpwd"))
@@ -93,7 +95,8 @@
 	  (progn
 	    (mew-pop-set-auth pnm auth)
 	    (funcall func pro pnm))
-	(mew-pop-debug "<AUTH>" "No preferred POP AUTH.\n"))))
+	(mew-pop-debug "<AUTH>" "No preferred POP AUTH.\n")
+	(mew-pop-command-wpwd2 pro pnm))))
    (t
     (mew-pop-command-pswd pro pnm))))
 
@@ -161,8 +164,11 @@
 
 (defun mew-pop-command-wpwd2 (pro pnm)
   (let ((directive (mew-pop-get-directive pnm))
+	(status (mew-pop-get-status pnm))
 	(bnm (mew-pop-get-bnm pnm)))
-    (mew-pop-message pnm "Stronger password scheme should be used!")
+    (if (string= status "auth")
+	(mew-pop-message pnm "No POP AUTH available!")
+      (mew-pop-message pnm "Stronger password scheme should be used!"))
     (mew-passwd-set-passwd (mew-pop-passtag pnm) nil)
     (if (eq directive 'exec)
 	(mew-summary-visible-buffer bnm))
@@ -482,7 +488,8 @@
 ;;;
 
 (defvar mew-pop-auth-alist
-  '(("CRAM-MD5" mew-pop-command-auth-cram-md5)))
+  '(("CRAM-MD5" mew-pop-command-auth-cram-md5)
+    ("PLAIN"    mew-pop-command-auth-plain)))
 
 (defsubst mew-pop-auth-get-func (auth)
   (nth 1 (mew-assoc-case-equal auth mew-pop-auth-alist 0)))
@@ -502,6 +509,18 @@
     (setq cram-md5 (mew-cram-md5 user passwd challenge))
     (mew-pop-process-send-string pro cram-md5)))
 
+(defun mew-pop-command-auth-plain (pro pnm)
+  (mew-pop-process-send-string pro "AUTH PLAIN")
+  (mew-pop-set-status pnm "auth-plain"))
+
+(defun mew-pop-command-pwd-plain (pro pnm)
+  (let* ((prompt (format "POP PLAIN password (%s): "
+                         (mew-pop-get-account pnm)))
+         (passwd (mew-pop-input-passwd prompt pnm))
+	 (user (mew-pop-get-user pnm))
+	 (plain (mew-base64-encode-string (format "\0%s\0%s" user passwd))))
+    (mew-pop-process-send-string pro "%s" plain)))
+
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
 ;;; Sub functions
@@ -618,7 +637,7 @@
 	 (pnm (mew-pop-info-name case))
 	 (buf (get-buffer-create (mew-pop-buffer-name pnm)))
 	 (no-msg (eq directive 'biff))
-	 process sshname sshpro sslname sslpro lport)
+	 process sshname sshpro sslname sslpro lport tls)
     (if (mew-pop-get-process pnm)
 	(message "Another POP process is running. Try later")
       (cond
@@ -630,7 +649,8 @@
 	  (when lport
 	    (setq process (mew-pop-open pnm "localhost" lport no-msg)))))
        (sslp
-	(setq sslpro (mew-open-ssl-stream server sslport))
+	(if (string= port sslport) (setq tls mew-tls-pop))
+	(setq sslpro (mew-open-ssl-stream case server sslport tls))
 	(when sslpro
 	  (setq sslname (process-name sslpro))
 	  (setq lport (mew-ssl-pnm-to-lport sslname))
@@ -798,7 +818,7 @@
 	    (when recovered
 	      (mew-pop-message
 	       pnm
-	       "%d message retrieved. %d messages are left due to an error."
+	       "%d message retrieved. %d messages are left due to an error"
 	       (- rttl lefts) lefts)
 	      (mew-summary-folder-cache-save))))
       (cond
@@ -908,7 +928,7 @@
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 1999-2003 Mew developing team.
+;; Copyright (C) 1999-2005 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
