@@ -395,11 +395,11 @@ guessed values."
   (let* ((msgid (mew-idstr-get-first-id
 		 (mew-header-get-value mew-message-id:)))
 	 (folder (car chosen))
-	 ;; ohter people's honest opinion and my honest opinion.
+	 ;; other people's honest opinion and my honest opinion.
 	 (oho info)
 	 (mho (cdr (assoc 'mew-refile-guess-by-thread info))))
     (when (and msgid chosen)
-      ;; if my opninion was right, I learn it.
+      ;; if my opinion was right, I learn it.
       ;; or a folder was not in other people's opinion,
       ;; I accept it.
       (catch 'match
@@ -604,13 +604,17 @@ with '\\[universal-argument]', it displays how the refile rules work in Message
 	  (regexp-quote mew-override-body-close)))
 
 (defun mew-summary-refile-override-body (folders-str)
-  (save-excursion
-    (when (mew-summary-goto-body 'after)
-      (when (looking-at mew-regex-override-body)
+  (let* ((open mew-override-body-open)
+	 (close mew-override-body-close)
+	 (len (+ (length folders-str) (length open) (length close))))
+    (save-excursion
+      (when (mew-summary-goto-body 'after)
+	(when (looking-at mew-regex-override-body)
+	  (mew-elet
+	   (delete-region (point) (match-end 0))))
 	(mew-elet
-	 (delete-region (point) (match-end 0))))
-      (mew-elet
-       (insert-and-inherit mew-override-body-open folders-str mew-override-body-close)))))
+	 (insert-and-inherit open folders-str close))))
+    len))
 
 (defun mew-summary-refile-remove-body ()
   (save-excursion
@@ -635,6 +639,18 @@ with '\\[universal-argument]', it displays how the refile rules work in Message
 	(insert "== src=" fld " dst=" folders-str " id=" msg-id)
 	(insert " date=" (mew-time-ctz-to-logtime (current-time)) "\n")))))
 
+(defun mew-summary-refile-unlog (fld)
+  (save-excursion
+    (let ((msg-id (mew-summary-my-id))
+	  start)
+      (set-buffer (get-buffer-create (mew-refile-log-buffer fld)))
+      (goto-char (point-min))
+      (when (search-forward (concat " id=" msg-id))
+	(beginning-of-line)
+	(setq start (point))
+	(forward-line)
+	(delete-region start (point))))))
+
 (defun mew-refile-decode-subject ()
   (save-excursion
     (goto-char (point-min))
@@ -670,9 +686,8 @@ with '\\[universal-argument]', it displays how the refile rules work in Message
      (t
       (if exp-flds
 	  (setq folders exp-flds)
-	(unless auto
+	(unless (or auto (mew-sinfo-get-disp-msg))
 	  ;; need to make a cache or a message buffer.
-	  (mew-summary-toggle-disp-msg 'on)
 	  (mew-summary-display nil))
 	(setq buf (mew-cache-hit fld msg))
 	(unless buf
@@ -713,6 +728,7 @@ with '\\[universal-argument]', it displays how the refile rules work in Message
 			  (re-search-backward (mew-regex-sumsyn-msg msg) nil t))
 		  (mew-refile-reset msg)
 		  (mew-refile-set msg folders)
+		  (if cur-folders (mew-summary-refile-unlog fld))
 		  (mew-summary-refile-log fld folders-str)
 		  (mew-summary-refile-override-body folders-str)
 		  ;; marked in mew-mark-put-mark
@@ -720,6 +736,7 @@ with '\\[universal-argument]', it displays how the refile rules work in Message
 	   (t
 	    (mew-refile-reset msg)
 	    (mew-refile-set msg folders)
+	    (if cur-folders (mew-summary-refile-unlog fld))
 	    (mew-summary-refile-log fld folders-str)))
 	  (mew-summary-refile-override-body folders-str)
 	  (mew-mark-put-mark mew-mark-refile no-msg)
@@ -802,9 +819,9 @@ refile folder."
 (defun mew-summary-auto-refile (&optional mew-mark-review-only)
   "Refile each message in the folder automatically. If 
 'mew-refile-auto-refile-skip-any-mark' is non-nil,
-any previousely marked message will be skipped.
+any previously marked message will be skipped.
 If '\\[universal-argument]' is specified, only messages marked with
-'mew-mark-review' will be conserned."
+'mew-mark-review' will be concerned."
   (interactive "P")
   (mew-pickable
    (mew-summary-not-in-draft
@@ -894,7 +911,7 @@ This is very convenient to refile all messages picked by '\\[mew-summary-pick-ma
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 1994-2003 Mew developing team.
+;; Copyright (C) 1994-2005 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
