@@ -161,34 +161,37 @@ with -4. See also 'mew-summary-form-size-0k' and 'mew-summary-form-size-huge'."
 
 (defun mew-summary-form-extract-addr (addr)
   "Extract addr according to 'mew-summary-form-extract-rule'."
-  (let* ((func (if mew-addrbook-for-summary
-		   (mew-addrbook-func mew-addrbook-for-summary)))
-	 (raw (or (mew-addrstr-parse-address addr) ""))
-	 (rules mew-summary-form-extract-rule)
-	 rule ret nickname)
-    (catch 'matched
-      (while rules
-	(setq rule (car rules))
-	(setq rules (cdr rules))
-	(cond
-	 ((and (eq rule 'name)
-	       (or (string-match "^\"\\([^\"]+\\)\"[ \t]*<[^>]+>" addr)
-		   (string-match "^\\([^<]+\\)<[^>]+>" addr)))
-	  (throw 'matched (setq ret (mew-chop (match-string 1 addr)))))
-	 ((and (eq rule 'comment)
-	       (string-match "^[^(]+(\\(.+\\))" addr))
-	  (throw 'matched (setq ret (mew-chop (match-string 1 addr)))))
-	 ((eq rule 'address)
-	  (throw 'matched (setq ret raw)))
-	 ((and (eq rule 'nickname)
-	       ;; set nickname here for efficiency
-	       (or nickname
-		   (setq nickname (if func (funcall func raw)))))
-	  (throw 'matched (setq ret nickname)))
-	 ((and (stringp rule)
-	       (string-match rule addr))
-	  (throw 'matched (setq ret (mew-chop (match-string 1 addr))))))))
-    (or ret addr)))
+  (condition-case nil
+      (let* ((func (if mew-addrbook-for-summary
+		       (mew-addrbook-func mew-addrbook-for-summary)))
+	     (raw (or (mew-addrstr-parse-address addr) ""))
+	     (rules mew-summary-form-extract-rule)
+	     rule ret nickname)
+	(catch 'matched
+	  (while rules
+	    (setq rule (car rules))
+	    (setq rules (cdr rules))
+	    (cond
+	     ((and (eq rule 'name)
+		   (or (string-match "^\"\\([^\"]+\\)\"[ \t]*<[^>]+>" addr)
+		       (string-match "^\\([^<]+\\)<[^>]+>" addr)))
+	      (throw 'matched (setq ret (mew-chop (match-string 1 addr)))))
+	     ((and (eq rule 'comment)
+		   (string-match "^[^(]+(\\(.+\\))" addr))
+	      (throw 'matched (setq ret (mew-chop (match-string 1 addr)))))
+	     ((eq rule 'address)
+	      (throw 'matched (setq ret raw)))
+	     ((and (eq rule 'nickname)
+		   ;; set nickname here for efficiency
+		   (or nickname
+		       (setq nickname (if func (funcall func raw)))))
+	      (throw 'matched (setq ret nickname)))
+	     ((and (stringp rule)
+		   (string-match rule addr))
+	      (throw 'matched (setq ret (mew-chop (match-string 1 addr))))))))
+	(or ret addr))
+    ;; a version of downcase causes error if argument is non-ascii.
+    (error mew-error-broken-address)))
 
 (defun mew-summary-form-from ()
   "A function to return an address.
@@ -377,7 +380,7 @@ of thread indent position is returned."
 	   (mew-refile-reset msg)
 	   (mew-refile-set msg (mew-split mark-or-dst ?,))
 	   (mew-summary-refile-log folder mark-or-dst)
-	   (mew-summary-refile-override-body mark-or-dst)
+	   (setq med (+ med (mew-summary-refile-override-body mark-or-dst)))
 	   (mew-mark-put mew-mark-refile))
 	  ((mew-characterp mark-or-dst) ;; mew-inbox-action-alist
 	   (mew-mark-put mark-or-dst))
@@ -620,7 +623,7 @@ to the range which you specify.
 In a REMOTE folder: messages in the server's folder are cached
 according to the range which you specify. If
 'mew-pop-header-only'/'mew-imap-header-only'/'mew-nntp-header-only' is
-non-nil, only headers of messages are cacched. If executed with
+non-nil, only headers of messages are cached. If executed with
 '\\[universal-argument]', these variables are considered reversed."
   (interactive "P")
   (mew-summary-only
@@ -703,7 +706,7 @@ non-nil, only headers of messages are cacched. If executed with
 	 (t2 (mew-file-get-time cache)))
     (if (and (null t1)
 	     (file-directory-p dir)
-	     (mew-dir-messages (mew-expand-folder dir)))
+	     (mew-dir-messages dir))
 	t
       (mew-compare-times t1 t2))))
 
@@ -737,7 +740,7 @@ non-nil, only headers of messages are cacched. If executed with
 (defun mew-summary-folder-cache-load ()
   (let* ((folder (mew-summary-folder-name 'ext))
 	 (cache (mew-expand-folder folder mew-summary-cache-file))
-	 refile)
+	 refile refs)
     (when (and (file-readable-p cache)
 	       (mew-summary-folder-cache-newp))
       (mew-elet
@@ -750,8 +753,9 @@ non-nil, only headers of messages are cacched. If executed with
 	   (setq mew-summary-buffer-raw nil)
 	 (setq mew-summary-buffer-raw t))
        (mew-sinfo-load)
+       (setq refs (mew-summary-mark-collect mew-mark-refile))
        (setq refile (mew-summary-mark-recover
-		     (mew-sinfo-get-mark-hist) (mew-sinfo-get-refile)))
+		     (mew-sinfo-get-mark-hist) (mew-sinfo-get-refile) refs))
        (mew-sinfo-set-refile refile)
        (mew-summary-set-count-line)
        (set-buffer-modified-p nil)))))
@@ -804,7 +808,7 @@ non-nil, only headers of messages are cacched. If executed with
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 1996-2003 Mew developing team.
+;; Copyright (C) 1996-2005 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
