@@ -15,11 +15,12 @@ A file name of a certificate should be 'cert-hash.0'.
 
 (defvar mew-ssl-verify-level 1
   "Verification level of server's certificate.
-1 - verify server's cetificate if present. If verification failed, an
-    SSL connection is not created. If not present, an SSL connection
+0 - no verification.
+1 - verify server's certificate if present. If verification failed, an
+    SSL/TLS connection is not created. If not present, an SSL/TLS connection
     is created.
-2 - verify server's cetificate. If verification failed, an SSL
-    connection is not created. If not present, an SSL connection is
+2 - verify server's certificate. If verification failed, an SSL/TLS
+    connection is not created. If not present, an SSL/TLS connection is
     not created.
 3 - verify server's certificate which locally installed (not one from
     the server).")
@@ -32,7 +33,17 @@ A file name of a certificate should be 'cert-hash.0'.
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
-;;; SSL info
+;;; Magic words
+;;;
+
+(defconst mew-tls-smtp "smtp")
+(defconst mew-tls-pop  "pop3")
+(defconst mew-tls-nntp "nntp")
+(defconst mew-tls-imap "imap") ;; xxx stunnel does not support this.
+
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;;;
+;;; SSL/TLS info
 ;;;
 
 (defvar mew-ssl-info-list '("status" "try" "file"))
@@ -57,41 +68,48 @@ A file name of a certificate should be 'cert-hash.0'.
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
-;;; Executing SSL
+;;; Executing SSL/TLS
 ;;;
 
-(defun mew-ssl-options (server remoteport localport)
+(defun mew-ssl-options (case server remoteport localport tls)
   (if (= mew-ssl-ver 3)
-      `("-c" "-f"
-	"-a" ,(expand-file-name mew-ssl-cert-directory)
-	"-d" ,(format "localhost:%d" localport)
-	"-v" ,(int-to-string mew-ssl-verify-level)
-	"-D" "debug"
-	"-P" "none"
-	"-r" ,(format "%s:%s" server remoteport)
-	,@mew-prog-ssl-arg)
-    (let ((file (mew-make-temp-name))) ;; xxx when should this be deleted?
+      (let (args)
+	(setq args
+	      `("-c" "-f"
+		"-a" ,(expand-file-name (mew-ssl-cert-directory case))
+		"-d" ,(format "localhost:%d" localport)
+		"-v" ,(int-to-string (mew-ssl-verify-level case))
+		"-D" "debug"
+		"-P" "none"
+		"-r" ,(format "%s:%s" server remoteport)
+		,@mew-prog-ssl-arg))
+	(if tls (setq args (cons "-n" (cons tls args))))
+	args)
+    (let ((file (mew-make-temp-name)))
       (with-temp-buffer
 	(insert "client=yes\n")
 	(insert "pid=\n")
-	(insert "verify=" (int-to-string mew-ssl-verify-level) "\n")
+	(insert (format "verify=%d\n" (mew-ssl-verify-level case)))
 	(insert "foreground=yes\n")
 	(insert "debug=debug\n")
-	(insert "CApath=" (expand-file-name mew-ssl-cert-directory) "\n")
+	(insert "CApath=" (expand-file-name (mew-ssl-cert-directory case)) "\n")
 	(insert (format "[%d]\n" localport))
 	(insert (format "accept=localhost:%d\n" localport))
 	(insert (format "connect=%s:%s\n" server remoteport))
+	(if tls (insert (format "protocol=%s\n" tls)))
 	(mew-frwlet
 	 mew-cs-dummy mew-cs-text-for-write
 	 ;; NEVER use call-process-region for privacy reasons
 	 (write-region (point-min) (point-max) file nil 'no-msg))
 	(list file)))))
 
-(defun mew-open-ssl-stream (server serv)
-  "Open SSL stream for SERVER's SERV.
-This function returns a process when an SSL connection is created
-successfully. A local port number can be obtained the process name
-after ':'."
+(defun mew-open-ssl-stream (case server serv tls)
+  "Open an SSL/TLS stream for SERVER's SERV.
+This function returns a process when an SSL/TLS connection is created
+successfully. 
+If TLS is nil, an SSL connection is created.
+If TLS is a magic word for 'stunnel', a TLS connection is created.
+A local port number can be obtained the process name after ':'. "
   (cond
    ((not (and (stringp server) (stringp serv)))
     nil)
@@ -116,23 +134,22 @@ after ':'."
 	  (setq pros (cdr pros))))
       (if pro
 	  pro
-	(message "Creating an SSL connection...")
+	(message "Creating an SSL/TLS connection...")
 	(setq pro nil)
 	(setq buf (generate-new-buffer (concat mew-buffer-prefix "ssl")))
 	(catch 'loop
 	  (while (< i N)
 	    (setq name (mew-ssl-info-name server remoteport localport))
-	    (setq opts (mew-ssl-options server remoteport localport))
+	    (setq opts (mew-ssl-options case server remoteport localport tls))
 	    (setq pro (apply 'start-process name buf mew-prog-ssl opts))
 	    ;; An error would occur. So, let's exit in the case.
-	    (mew-timing)
 	    (cond
 	     ((not (processp pro))
-	      (message "Creating an SSL connection...FAILED")
+	      (message "Creating an SSL/TLS connection...FAILED")
 	      (throw 'loop nil))
 	     ((not (memq (process-status pro) '(run)))
 	      (delete-process pro)
-	      (message "Creating an SSL connection...FAILED")
+	      (message "Creating an SSL/TLS connection...FAILED")
 	      (throw 'loop nil)))
 	    ;; stunnel is now running.
 	    (process-kill-without-query pro)
@@ -152,11 +169,11 @@ after ':'."
 	(mew-ssl-set-status pnm nil)
 	(if (not bound)
 	    (progn
-	      (message "Creating an SSL connection...FAILED")
+	      (message "Creating an SSL/TLS connection...FAILED")
 	      nil)
 	  ;; "stunnel" does not gain access to the remote port
 	  ;; until a tunneled connection is created.
-	  ;; So, we need to check the SSL tunnel with a dummy
+	  ;; So, we need to check the SSL/TLS tunnel with a dummy
 	  ;; tunneled connection here.
 	  (set-process-filter pro 'mew-ssl-filter2)
 	  (setq dummy (open-network-stream " *Mew dummy*" nil "localhost" localport))
@@ -164,12 +181,12 @@ after ':'."
 	  (if (processp dummy) (delete-process dummy))
 	  (if (eq (mew-ssl-get-status pnm) t)
 	      (progn
-		(message "Creating an SSL connection...done")
+		(message "Creating an SSL/TLS connection...done")
 		(set-process-filter pro 'mew-ssl-filter3)
 		pro)
 	    ;; verify-failure
 	    (delete-process pro)
-	    (message "Creating an SSL connection...FAILED (cert verify failure)")
+	    (message "Creating an SSL/TLS connection...FAILED (cert verify failure)")
 	    nil)))))))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
@@ -185,7 +202,7 @@ after ':'."
       (insert (format "\n<%s>\n%s\n" label string)))))
 
 (defun mew-ssl-filter1 (process string)
-  (mew-ssl-debug "SSL: " string)
+  (mew-ssl-debug "SSL/TLS: " string)
   (let ((pnm (process-name process)))
     (cond
      ((string-match "bound to" string)
@@ -198,7 +215,7 @@ after ':'."
       (mew-ssl-set-status pnm 'bind-failure)))))
 
 (defun mew-ssl-filter2 (process string)
-  (mew-ssl-debug "SSL: " string)
+  (mew-ssl-debug "SSL/TLS: " string)
   (let ((pnm (process-name process)))
     (cond
      ((string-match "Negotiated ciphers\\|opened with SSL" string)
@@ -209,7 +226,7 @@ after ':'."
       (mew-ssl-set-status pnm 'verify-failure)))))
 
 (defun mew-ssl-filter3 (process string)
-  (mew-ssl-debug "SSL: " string))
+  (mew-ssl-debug "SSL/TLS: " string))
 
 (defun mew-ssl-sentinel (process event)
   (let* ((pnm (process-name process))
@@ -219,7 +236,7 @@ after ':'."
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
-;;; SSL version check 
+;;; stunnel version check 
 ;;;
 
 (defun mew-ssl-setup ()
@@ -234,7 +251,7 @@ after ':'."
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 2002-2003 Mew developing team.
+;; Copyright (C) 2002-2005 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
