@@ -215,7 +215,7 @@ This macro is used to prohibit using a command in Summary mode."
 
 (defun mew-summary-get-region ()
   "Get a region according to 'mew-summary-region-include-cursor-line'
-and retern (beg . end)."
+and return (beg . end)."
   (save-excursion
     (let ((beg (region-beginning))
 	  (end (region-end)))
@@ -445,13 +445,15 @@ The keys that are defined for both Summary mode and Virtual mode are:
 	In a REMOTE folder: messages in the server's folder are cached
 	according to the range which you specify. If
 	'mew-pop-header-only'/'mew-imap-header-only'/'mew-nntp-header-only' is
-	non-nil, only headers of messages are cacched. If executed with
+	non-nil, only headers of messages are cached. If executed with
 	'\\[universal-argument]', these variables are considered reversed.
 
 \\[mew-summary-goto-folder]	Go to the folder which you specify.  If executed with
 	'\\[universal-argument]', the cursor always goes to the bottom of Summary mode.
 
-\\[mew-summary-send]	Write a message. A new draft is prepared in Draft mode.
+\\[mew-summary-write]	Write a message. A new draft is prepared in Draft mode.
+	If called with '\\[universal-argument]', the From: address of
+	the current message is copied to To: in a draft.
 
 \\[mew-summary-reply]	Answer to this message. A new draft is prepared	in Draft mode.
 	Mew automatically decides To: and Cc:.
@@ -485,7 +487,7 @@ The keys that are defined for both Summary mode and Virtual mode are:
 \\[mew-summary-display-review-down]	Jump to the message marked with	'*' below.
 \\[mew-summary-display-review-up]	Jump to the message marked with '*' above.
 
-\\[mew-summary-escape]	Put the escap mark '$'.
+\\[mew-summary-escape]	Put the escape mark '$'.
 
 \\[mew-summary-unshar]	Apply 'unshar' on messages marked with '*'.
 \\[mew-summary-uudecode]	Apply 'uudecode' on messages marked with '*'.
@@ -497,7 +499,7 @@ The keys that are defined for both Summary mode and Virtual mode are:
 \\[mew-summary-undo]	Cancel the mark on this message.
 \\[mew-summary-undo-all]	Cancel all marks according to what you input.
 
-\\[mew-summary-mark-regexp]	Put the '*' mark onto Mall messages
+\\[mew-summary-mark-regexp]	Put the '*' mark onto all messages
 	matched to a regular expression.
 
 \\[mew-summary-mark-all]	Put the '*' mark onto all messages which are not marked.
@@ -505,6 +507,7 @@ The keys that are defined for both Summary mode and Virtual mode are:
 \\[mew-summary-mark-escape]	Change the '*' mark into the '$' mark.
 \\[mew-summary-mark-undo-all]	Unmark all message marked with 'o'/'D'/'X'.
 \\[mew-summary-mark-swap]	Swap the '$' mark and the '*' mark.
+\\[mew-summary-exchange-marks]	Exchange the first input mark to the second one.
 
 \\[mew-summary-mark-retrieve-message]	Retrieve the rest of a truncated('T') message marked with '*'.
 	In a LOCAL folder: 'mew-input-case' is used for a case.  
@@ -542,7 +545,7 @@ The keys that are defined for both Summary mode and Virtual mode are:
 \\[mew-summary-execute-external] Execute an external command according to Content-Type:.
 	If called with '\\[universal-argument]', Content-Type: is asked.
 
-\\[mew-summary-execute-command] Execute an inputed command.
+\\[mew-summary-execute-command] Execute an inputted command.
 
 \\[mew-summary-recenter]	Make the current line to the center of Summary mode.
 
@@ -614,7 +617,7 @@ The keys that are defined for both Summary mode and Virtual mode are:
 
 \\[mew-summary-toggle-8bit]	Toggle 8bit mode(i.e. 'mew-use-8bit').
 \\[mew-summary-cache-clean-up]	Clean-up caches of analyzed messages.
-\\[mew-summary-toggle-warning]	Toggle waring level.
+\\[mew-summary-toggle-warning]	Toggle warning level.
 	If 'mew-warning-field-level' is 2, set it to 1.
 	If 'mew-warning-field-level' is 1, set it to 2.
 \\[mew-summary-toggle-policy]	Toggle decode policy(i.e. 'mew-decode-broken').
@@ -628,7 +631,7 @@ Virtual mode.
 	If already marked with 'o', it prints where this message
 	will be refiled. This can overlay other marks.
 	When it	overlays, the cursor stays on the message.
-	If it marks newly,displays the next message.
+	If it marks newly, displays the next message.
 	If executed with'\\[universal-argument]', it displays how the refile rules work
 	in Message mode.
 
@@ -780,6 +783,9 @@ is equivalent to
   (make-local-variable 'tab-width)
   (make-local-variable 'search-invisible)
   (setq search-invisible nil)
+  (make-local-variable 'line-move-ignore-invisible)
+  (setq line-move-ignore-invisible t)
+  (make-local-variable 'search-invisible)
   (cond
    (mew-gemacs-p
     (jit-lock-register 'mew-summary-cook-region))
@@ -814,7 +820,7 @@ is equivalent to
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 1996-2003 Mew developing team.
+;; Copyright (C) 1996-2005 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
