@@ -49,16 +49,16 @@
       (mew-summary-goto-message)
       (cond
        ((eq (mew-sinfo-get-direction) 'up)
-	(when (re-search-backward mew-regex-sumsyn-short nil t)
-	  (setq fld (mew-sumsyn-folder-name))
-	  (setq next (mew-sumsyn-message-number))))
+	(when (re-search-backward mew-regex-msg-show nil t)
+	  (setq fld (mew-summary-folder-name))
+	  (setq next (mew-summary-message-number))))
        ((eq (mew-sinfo-get-direction) 'down)
 	(if (mew-decode-syntax-end)
 	    (goto-char (mew-decode-syntax-end))
 	  (forward-line))
-	(when (re-search-forward mew-regex-sumsyn-short nil t)
-	  (setq fld (mew-sumsyn-folder-name))
-	  (setq next (mew-sumsyn-message-number))))))
+	(when (re-search-forward mew-regex-msg-show nil t)
+	  (setq fld (mew-summary-folder-name))
+	  (setq next (mew-summary-message-number))))))
     ;; should get the cursor back for display
     (save-excursion
       (if (and fld next
@@ -180,7 +180,7 @@ or part. If it is already displayed, nothing changes.
 
  (4) If called internally and REDISPLAY is 't', this function displays
 the current message or part. Even if it is already displayed, this
-function displays it again getting gack to the beginning."
+function displays it again getting back to the beginning."
   (interactive "P")
   (when (or redisplay (mew-sinfo-get-disp-msg) (interactive-p))
     (mew-summary-msg-or-part
@@ -200,7 +200,7 @@ function displays it again getting gack to the beginning."
 	   (progn
 	     (mew-summary-toggle-disp-msg 'on)
 	     (mew-window-configure 'message)
-	     ;; messge buffer
+	     ;; message buffer
 	     (mew-current-set fld (or msg omsg) part)
 	     (mew-minfo-set-summary vfld)
 	     (cond
@@ -427,7 +427,11 @@ displays it."
 ;;;
 
 (defun mew-summary-display-asis ()
-  "Insert this message or part into Message mode in the raw format."
+  "Insert this message or part into Message mode in the raw format.
+This command treats PGP/MIME transparent. That is an encrypted/signed
+part is displayed as a decrypted/verified part. Also, if this command
+is used for a message whose entire body is encrypted/signed, 
+a decrypted/verified body is displayed."
   (interactive)
   (mew-summary-msg-or-part
    (let* ((fld (mew-summary-folder-name))
@@ -502,7 +506,7 @@ If called with '\\[universal-argument]', it stays writable."
       (if (mew-folder-draftp fld) mew-cs-m17n mew-cs-autoconv) mew-cs-dummy
       (if arg
 	  (switch-to-buffer (mew-find-file-noselect2 file))
-	(view-buffer (mew-find-file-noselect2 file)))))))
+	(view-buffer (mew-find-file-noselect2 file) 'kill-buffer))))))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
@@ -514,25 +518,21 @@ If called with '\\[universal-argument]', it stays writable."
   (interactive)
   (mew-summary-msg-or-part
    (let* ((win (selected-window))
-	  fld msg cache lst ent svr-date snd rcv svr date tmp)
+	  (fld (mew-summary-folder-name))
+	  (msg (mew-summary-message-number2))
+	  lst ent svr-date snd rcv svr date tmp)
+     (let ((mew-use-full-window nil))
+       (mew-summary-display nil))
      (save-excursion
-       (mew-summary-goto-message)
-       (when (mew-sumsyn-match mew-regex-sumsyn-short)
-	 (setq fld (mew-sumsyn-folder-name))
-	 (setq msg (mew-sumsyn-message-number))) ;; msg is never nil
-       (setq cache (mew-cache-hit fld msg))
-       (cond
-	(cache
-	 (set-buffer cache)
-	 (setq lst (mew-header-get-value mew-received: 'as-list)))
-	(t
-	 (with-temp-buffer
-	   (mew-insert-message fld msg mew-cs-autoconv
-			       mew-header-reasonable-size)
-	   (setq lst (mew-header-get-value mew-received: 'as-list))))))
+       (set-buffer (or (save-excursion
+			 (set-buffer (mew-buffer-message))
+			 (if (mew-msghder-p) (current-buffer)))
+		       ;; header exists only in cache if multipart
+		       (mew-cache-hit fld msg)))
+       (setq lst (mew-header-get-value mew-received: 'as-list)))
      (mew-summary-toggle-disp-msg 'on)
      (mew-window-configure 'message)
-     ;; messge buffer
+     ;; message buffer
      (mew-summary-display-preamble)
      (setq lst (nreverse lst))
      (while lst
@@ -782,7 +782,7 @@ over the window. Type '\\[mew-summary-prev-page]' to see them when a message is
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 1996-2003 Mew developing team.
+;; Copyright (C) 1996-2005 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
