@@ -58,20 +58,36 @@
 ;;; Sending
 ;;;
 
-(defun mew-summary-postp ()
-  (cond
-   ((mew-summary-p)
-    (mew-folder-nntpp (mew-summary-folder-name 'ext)))
-   ((mew-virtual-p)
-    (mew-folder-nntpp (mew-virtual-folder-name)))
-   (t
-    (mew-folder-nntpp (mew-proto mew-case-output)))))
-
+(defun mew-summary-write (&optional from)
+  "Write a message. A new draft is prepared in Draft mode.
+If called with '\\[universal-argument]', the From: address of
+the current message is copied to To: in a draft."
+  (interactive "P")
+  (if (null from)
+      (mew-summary-send)
+    (mew-summary-msg-or-part
+     (let ((fld (mew-summary-folder-name))
+	   (msg (mew-summary-message-number2))
+	   to)
+       (if (not (and fld msg))
+	   (message "No message")
+	 (save-excursion
+	   (set-buffer (or (save-excursion
+			     (set-buffer (mew-buffer-message))
+			     (if (mew-msghder-p) (current-buffer)))
+			   ;; header exists only in cache if multipart
+			   (mew-cache-hit fld msg)))
+	   (setq to (mew-addrstr-parse-address (mew-header-get-value mew-from:))))
+	 (mew-summary-send to)
+	 (goto-char (point-min))
+	 (if (search-forward mew-subj: nil t)
+	     (end-of-line)))))))
+  
 (defun mew-summary-send (&optional to cc subject newsgroups)
   "Write a message. A new draft is prepared in Draft mode."
   (interactive)
   (let ((draft (mew-folder-new-message mew-draft-folder)))
-    (if (mew-summary-postp)
+    (if (mew-folder-nntpp (mew-summary-physical-folder))
 	(if (null newsgroups) (setq newsgroups ""))
       (when (and mew-ask-to (null to))
         (setq to (mew-input-address (concat mew-to: " "))))
@@ -173,7 +189,7 @@
 
 (defun mew-summary-reply (&optional replysender)
   "Reply to this message. A new draft is prepared in Draft mode. 
-Values of To:, Cc:, and Newsgroups: are prepared accoring to
+Values of To:, Cc:, and Newsgroups: are prepared according to
 three alists.
 
 \(1) If called with '\\[universal-argument]', replying to the
@@ -443,7 +459,7 @@ attached."
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 1996-2003 Mew developing team.
+;; Copyright (C) 1996-2005 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
