@@ -28,7 +28,6 @@
       (switch-to-buffer case:folder)
       (mew-set-buffer-cs mew-cs-m17n)
       (when (and p-folder (mew-folder-virtualp case:folder))
-	(mew-vinfo-set-thread-p t)
 	(mew-vinfo-set-parent-folder p-folder))
       (unless (mew-folder-virtualp case:folder) (mew-summary-folder-cache-load))
       (unless (string= ofolder case:folder) (mew-window-configure 'summary)))
@@ -42,9 +41,7 @@
       (mew-sinfo-set-folder (mew-case:folder-folder case:folder))
       (if (mew-folder-virtualp case:folder)
 	  (progn
-	    (when p-folder
-	      (mew-vinfo-set-thread-p t)
-	      (mew-vinfo-set-parent-folder p-folder))
+	    (if p-folder (mew-vinfo-set-parent-folder p-folder))
 	    (mew-virtual-mode))
 	(mew-summary-mode)
 	(if mew-summary-trace-directory (cd (mew-expand-folder case:folder)))
@@ -64,38 +61,44 @@ Summary mode."
   (interactive "P")
   (let* ((proto (mew-proto-to-go (mew-summary-folder-name 'ext)))
 	 (case1 (if (mew-folder-remotep proto)
-		   (mew-sinfo-get-case) ;; a remote folder
-		 mew-case-input)) ;; a local/virtual folder
+		    (mew-sinfo-get-case) ;; a remote folder
+		  mew-case-input)) ;; a local/virtual folder
 	 (inbox (mew-proto-inbox-folder	proto case1))
-
 	 (case:folder (mew-input-folder case1 inbox))
-	 (case (mew-case:folder-case case:folder))
-	 (folder (mew-case:folder-folder case:folder))
-	 buf win frame goend folder-alist sep)
-    (when (mew-folder-imapp folder)
-      (setq folder-alist (mew-imap-folder-alist case))
-      (setq sep (mew-imap-separator case))
-      (unless (or (assoc folder folder-alist)
-		  (assoc (concat folder sep) folder-alist))
-	(message "%s does not exist" case:folder)
-	(setq case:folder nil)))
-    (when case:folder
-      (when mew-use-other-frame-for-summary
-	(if (setq buf (get-buffer case:folder))
-	    (if (setq win (get-buffer-window buf 0))
-		(progn
-		  (setq frame (window-frame win))
-		  (raise-frame frame)
-		  (select-frame frame)
-		  ;; Ensure, if possible, that frame gets input focus.
-		  (if (eq window-system 'w32)
-		      (w32-focus-frame frame)
-		    (when focus-follows-mouse
-		      (set-mouse-position
-		       (selected-frame) (1- (frame-width)) 0))))
-	      (select-frame (make-frame)))
-	  (select-frame (make-frame))))
-      (mew-summary-visit-folder case:folder goend))))
+	 case folder buf win frame folder-alist sep)
+    (if (null case:folder)
+	(message "The folder does not exist")
+      (setq case (mew-case:folder-case case:folder))
+      (setq folder (mew-case:folder-folder case:folder))
+      (cond
+       ((mew-folder-imapp folder)
+	(setq folder-alist (mew-imap-folder-alist case))
+	(setq sep (mew-imap-separator case))
+	(unless (or (assoc folder folder-alist)
+		    (assoc (concat folder sep) folder-alist))
+	  (message "%s does not exist" case:folder)
+	  (setq case:folder nil)))
+       ((mew-folder-nntpp folder)
+	(unless (assoc folder (mew-nntp-folder-alist case))
+	  (message "%s does not exist" case:folder)
+	  (setq case:folder nil))))
+      (when case:folder
+	(when mew-use-other-frame-for-summary
+	  (if (setq buf (get-buffer case:folder))
+	      (if (setq win (get-buffer-window buf 0))
+		  (progn
+		    (setq frame (window-frame win))
+		    (raise-frame frame)
+		    (select-frame frame)
+		    ;; Ensure, if possible, that frame gets input focus.
+		    (if (eq window-system 'w32)
+			(w32-focus-frame frame)
+		      (when focus-follows-mouse
+			(set-mouse-position
+			 (selected-frame) (1- (frame-width)) 0))))
+		(select-frame (make-frame)))
+	    (select-frame (make-frame))))
+	(mew-summary-visit-folder case:folder goend)))))
 
 (defun mew-summary-visit-folder (folder &optional goend no-ls)
   (let ((dir (mew-expand-folder folder))
@@ -481,7 +484,7 @@ visualize it in Message mode."
 	   ;; ((and (symbolp program) (eq program 'mew-mime-message/rfc822))
 	   ;; (funcall program cache stx))
 	   (t
-	    (message "Not supported yet.")))
+	    (message "Not supported yet")))
 	  (mew-summary-display-postscript 'no-hook))
       (select-window win))))
 
@@ -491,14 +494,18 @@ visualize it in Message mode."
 ;;;
 
 (defun mew-summary-execute-external (&optional arg)
-  "Execute an external command according to Content-Type:. 
+  "Execute an external command for the current part according to Content-Type:. 
+If a body is not displayed as a part, type '\\<mew-summary-mode-map>\\[mew-summary-analyze-again-alternative]' to display the body as a part. 
+Then choose the part and execute this command.
 If called with '\\[universal-argument]', Content-Type: is asked."
   (interactive "P")
   (mew-summary-msg-or-part
    (mew-summary-execute-base arg nil nil)))
 
 (defun mew-summary-execute-command (&optional arg)
-  "Execute an inputed command.
+  "Execute an inputted command for the current part.
+If a body is not displayed as a part, type '\\<mew-summary-mode-map>\\[mew-summary-analyze-again-alternative]' to display the body as a part. 
+Then choose the part and execute this command.
 If called with '\\[universal-argument]', options are asked."
   (interactive "P")
   (mew-summary-msg-or-part
@@ -660,7 +667,7 @@ any, are killed."
 	    (if (string-match "mew" (process-name (car pros)))
 		(delete-process (car pros)))
 	    (setq pros (cdr pros)))
-	  (if disp-msg (message "All SSH/SSL processes were killed")))
+	  (if disp-msg (message "All SSH/SSL/TLS processes were killed")))
       (cond
        ((not (processp process))
 	(if disp-msg (message "No process to kill. This buffer is unlocked anyway")))
@@ -675,10 +682,10 @@ any, are killed."
 	(delete-process process)
 	(if disp-msg (message "The process was killed")))
        (t
-	;; Local process or SSH/SSL
+	;; Local process or SSH/SSL/TLS
 	(delete-process process)
-	(if disp-msg (message "The process was killed"))))
-      (mew-summary-unlock))))
+	(if disp-msg (message "The process was killed")))))
+    (mew-summary-unlock)))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
@@ -727,7 +734,7 @@ any, are killed."
 	 (mew-erase-buffer)
 	 (cd dir)
 	 ;; mew-folder-local is dummy to let mewencode use
-	 ;; the embedded filiname
+	 ;; the embedded filename
 	 (call-process mew-prog-mime-decode tmp t nil
 		       "-d" "-u" "-" mew-folder-local)
 	 (mew-delete-file tmp)
@@ -1008,7 +1015,8 @@ folder."
      (mew-insert-file-contents srcfile)
      (goto-char (point-min))
      (mew-header-delete-lines (list mew-x-mew-uidl:))
-     (write-region (point-min) (point-max) dstfile nil 'no-msg))))
+     (write-region (point-min) (point-max) dstfile nil 'no-msg)
+     (mew-set-file-modes dstfile))))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
@@ -1032,6 +1040,7 @@ folder."
 	 (when (y-or-n-p "Delete this folder? ")
 	   (mew-delete-directory-recursively dir)
 	   (mew-local-folder-delete folder)
+	   (mew-nmz-folder-index-delete folder)
 	   (mew-summary-visit-folder mew-inbox-folder)
 	   (mew-kill-buffer buf))))
       ((mew-folder-imapp folder)
@@ -1048,6 +1057,7 @@ folder."
 		 (setq mew-summary-buffer-process-error nil))
 	     (mew-imap-folder-delete case folder)
 	     (mew-delete-directory-recursively dir) ;; cache
+	     (mew-nmz-folder-index-delete case:folder)
 	     (mew-summary-visit-folder mew-imap-inbox-folder)
 	     (mew-kill-buffer buf)))))))))
 
@@ -1065,12 +1075,13 @@ folder."
      (cond
       ((mew-folder-localp folder)
        (setq new-folder (mew-input-local-folder folder))
+       (setq new-dir (mew-expand-folder new-folder))
        (cond
 	((string= folder new-folder)
 	 (message "%s was not moved" folder))
+	((file-exists-p new-dir)
+	 (message "%s was not moved so %s is existed" folder new-folder))
 	(t
-	 (setq new-dir (mew-expand-folder new-folder))
-	 ;; xxx if new-dir exists?
 	 (rename-file dir new-dir)
 	 (mew-summary-switch-to-folder new-folder)
 	 (mew-kill-buffer buf)
@@ -1078,15 +1089,18 @@ folder."
 	     ;; xxx remove all related buffer?
 	     (mew-local-update 'force)
 	   (mew-local-folder-delete folder)
-	   (mew-local-folder-insert new-folder)))))
+	   (mew-local-folder-insert new-folder))
+	 (mew-nmz-folder-index-rename folder new-folder))))
       ((mew-folder-imapp folder)
        (setq new-folder (car (mew-input-refile-folders (list folder) t case mew-folder-imap)))
        (setq case:new-folder (mew-case-folder case new-folder))
+       (setq new-dir (mew-expand-folder case:new-folder))
        (cond
 	((string= folder new-folder)
 	 (message "%s was not moved" folder))
+	((file-exists-p new-dir)
+	 (message "%s was not moved so %s is existed" folder new-folder))
 	(t
-	 (setq new-dir (mew-expand-folder new-folder))
 	 (mew-imap-retrieve case 'rename case:folder case:new-folder)
 	 (mew-timing)
 	 (mew-rendezvous mew-summary-buffer-process)
@@ -1100,9 +1114,10 @@ folder."
 	   (if (mew-folder-node-p folder case)
 	       (if (y-or-n-p "Collect a folder list now? ")
 		   (mew-imap-update case)
-		 (mew-message-for-summary "Type '3\\[mew-status-update]' to collect a folder list."))
+		 (mew-message-for-summary "Type '3\\[mew-status-update]' to collect a folder list"))
 	     (mew-imap-folder-delete case folder)
-	     (mew-imap-folder-insert case new-folder))))))))))
+	     (mew-imap-folder-insert case new-folder))
+	   (mew-nmz-folder-index-rename case:folder case:new-folder)))))))))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
@@ -1164,7 +1179,7 @@ you choose 'Summary mode only', you can quickly put the delete
 ;;;
 
 (defun mew-summary-toggle-warning ()
-  "Toggle waring level.
+  "Toggle warning level.
 If 'mew-warning-field-level' is 2, set it to 1.
 If 'mew-warning-field-level' is 1, set it to 2."
   (interactive)
@@ -1271,11 +1286,23 @@ See also 'mew-ham-prog' and 'mew-ham-prog-args."
 	   (setq end (1- (point)))
 	   (message (concat "Learned as ham: " (mew-buffer-substring beg end)))))))))
 
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;;;
+;;; Search invisible
+;;;
+
+(defun mew-summary-toggle-invisible ()
+  (interactive)
+  (if (eq search-invisible t)
+      (setq search-invisible 'open)
+    (setq search-invisible t))
+  (message "'search-invisible' is set to '%s'" search-invisible))
+
 (provide 'mew-summary4)
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 1996-2003 Mew developing team.
+;; Copyright (C) 1996-2005 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
