@@ -189,7 +189,7 @@
     (let ((body (mew-syntax-get-part syntax)))
       (if (mew-syntax-multipart-p body)
 	  (mew-syntax-get-entry (mew-syntax-get-part syntax) nums)
-	;; nums sould be "1"
+	;; nums should be "1"
 	body)))
    ((mew-syntax-multipart-p syntax)
     (if (null nums)
@@ -403,8 +403,6 @@ If this is a cache message, both the unique id and the size are also shown."
   (cond
    ((or ext (mew-summary-p))
     (buffer-name))
-   ((mew-pickable-p)
-    (car (mew-vinfo-get-flds)))
    (t ;; Virtual mode
     (save-excursion
       (mew-summary-goto-message)
@@ -803,8 +801,9 @@ If this is a cache message, both the unique id and the size are also shown."
 	(mew-set '(ctm ctp) (nth i privacy))
 	(let ((case-fold-search t))
 	  (cond
-	   ((string-match "pgp"  ctp) (aset marks (* i 2) ?P))
-	   ((string-match "moss" ctp) (aset marks (* i 2) ?M)))
+	   ((string-match "pgp"   ctp) (aset marks (* i 2) ?P))
+	   ((string-match "pkcs"  ctp) (aset marks (* i 2) ?S)) ;; S/MIME
+	   ((string-match "moss"  ctp) (aset marks (* i 2) ?M)))
 	  (cond
 	   ((mew-case-equal mew-ct-mle ctm) (aset marks (1+ (* i 2)) ?E))
 	   ((mew-case-equal mew-ct-mls ctm) (aset marks (1+ (* i 2)) ?S)))
@@ -939,6 +938,7 @@ If this is a cache message, both the unique id and the size are also shown."
 (defsubst mew-in-decode-syntax-p ()
   (and (marker-position mew-marker-decode-syntax-begin)
        (marker-position mew-marker-decode-syntax-end)
+       (eq (current-buffer) (marker-buffer mew-marker-decode-syntax-begin))
        (>= (point) (marker-position mew-marker-decode-syntax-begin))
        (<  (point) (marker-position mew-marker-decode-syntax-end))))
 
@@ -1093,7 +1093,7 @@ If this is a cache message, both the unique id and the size are also shown."
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 1996-2003 Mew developing team.
+;; Copyright (C) 1996-2005 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
