@@ -51,7 +51,11 @@
 ;;; Toolbar functions
 ;;;
 
+(defvar mew-summary-toolbar nil)
+(defvar mew-draft-toolbar nil)
+
 (defun mew-summary-setup-decoration () nil)
+(defun mew-message-setup-decoration () nil)
 (defun mew-draft-setup-decoration   () nil)
 (defun mew-header-setup-decoration  () nil)
 
@@ -66,13 +70,34 @@
 ;;;
 
 (defsubst mew-message-set-end-of-message ()
-  (overlay-put (mew-minfo-get-overlay) 'before-string mew-end-of-message-string))
+  (overlay-put (mew-minfo-get-eom) 'before-string mew-end-of-message-string))
 
 (defsubst mew-message-set-end-of-part ()
-  (overlay-put (mew-minfo-get-overlay) 'before-string mew-end-of-part-string))
+  (overlay-put (mew-minfo-get-eom) 'before-string mew-end-of-part-string))
 
 (defsubst mew-message-set-end-of-nil ()
-  (overlay-put (mew-minfo-get-overlay) 'before-string nil))
+  (overlay-put (mew-minfo-get-eom) 'before-string nil))
+
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;;;
+;;; Veil
+;;;
+
+(defun mew-header-veil-make ()
+  (let ((ov (mew-overlay-make 1 1)))
+    (overlay-put ov 'invisible t)
+    (overlay-put ov 'before-string mew-header-veil-string)
+    (delete-overlay ov) ;; detach from the buffer
+    ov))
+
+(defun mew-toggle-header-veil (ov)
+  (cond
+   ((overlay-get ov 'invisible)
+    (overlay-put ov 'invisible nil)
+    (overlay-put ov 'before-string nil))
+   (t
+    (overlay-put ov 'invisible t)
+    (overlay-put ov 'before-string mew-header-veil-string))))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
@@ -86,6 +111,14 @@
   ;; dummy
   )
 
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;;;
+;;; Transient
+;;;
+
+(defun mew-mark-active-p ()
+  (and transient-mark-mode mark-active))
+
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
 ;;; X Face
@@ -115,7 +148,7 @@
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
-;;; SSL/SSH notification
+;;; SSL/SSH/TLS notification
 ;;;
 
 (defvar mew-secure-format " [Sec]")
@@ -125,7 +158,7 @@
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 1997-2003 Mew developing team.
+;; Copyright (C) 1997-2005 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
