@@ -239,8 +239,8 @@ threads are created, see 'mew-use-complete-thread'."
   (mew-pickable
    (when (mew-summary-exclusive-p)
      (let* ((ofolder (mew-summary-folder-name 'ext))
-	    (folder (mew-physical-folder ofolder))
-	    (vfolder (mew-folder-to-thread folder))
+	    (vfolder (mew-folder-to-thread (mew-physical-folder ofolder)))
+	    (folder (mew-summary-physical-folder))
 	    (disp (mew-sinfo-get-disp-msg))
 	    (ctime (mew-sinfo-get-cache-time))
 	    (case (mew-sinfo-get-case))
@@ -313,7 +313,6 @@ threads are created, see 'mew-use-complete-thread'."
 	 (mew-vinfo-set-top nil)
 	 (mew-vinfo-set-db db)
  	 (mew-vinfo-set-column column)
-	 (mew-vinfo-set-flds (list folder))
 	 ;;
 	 (message "Making thread (second pass)...")
 	 (setq tm3 (current-time))
@@ -1061,7 +1060,7 @@ The thread/message is specified with the mark(\\[set-mark-command])."
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 2000-2003 Mew developing team.
+;; Copyright (C) 2000-2005 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
