@@ -196,19 +196,22 @@ messages whose the field contains the word are automatically
 removed or refiled to 'mew-imap-spam-folder' or 'mew-imap-trash-folder'
 (if defined) while scanning %inbox."
   :group 'mew-imap
-  :type 'string)
+  :type '(choice (const :tag "Not use" nil)
+		 (string :tag "Spam field")))
 
 (defcustom mew-imap-spam-word nil
   "*The word of anti spam information to be used for IMAP spam filter. 
 See 'mew-imap-spam-field'."
   :group 'mew-imap
-  :type 'string)
+  :type '(choice (const :tag "Not use" nil)
+		 (string :tag "Spam word")))
 
 (defcustom mew-imap-spam-folder nil
   "*A folder to be used for IMAP spam filter. 
 See 'mew-imap-spam-field'."
   :group 'mew-imap
-  :type 'string)
+  :type '(choice (const :tag "Not use" nil)
+		 (string :tag "Spam folder")))
 
 ;; must be here
 (defvar mew-basic-folders
@@ -276,7 +279,7 @@ is re-edited."
   :type 'hook)
 
 (defcustom mew-draft-mode-edit-again-hook nil
-  "*Hook called in Draft mode when a message returned with the old sytale
+  "*Hook called in Draft mode when a message returned with the old style
 is edited again."
   :group 'mew-draft
   :type 'hook)
@@ -305,7 +308,7 @@ Note that this hook is called before composition of the message."
   :type 'hook)
 
 (defcustom mew-post-hook nil
-  "*Hook called before posting/queuing  a NetNews message in Draft mode.
+  "*Hook called before posting/queuing a NetNews message in Draft mode.
 Note that this hook is called before composition of the message."
   :group 'mew-draft
   :type 'hook)
@@ -317,7 +320,7 @@ Note that this hook is called after composition of the message."
   :type 'hook)
 
 (defcustom mew-real-post-hook nil
-  "*Hook called before sending/queuing a NewNews message in Draft mode.
+  "*Hook called before sending/queuing a NetNews message in Draft mode.
 Note that this hook is called after composition of the message."
   :group 'mew-draft
   :type 'hook)
@@ -500,7 +503,7 @@ For more infomation, see the document of '\\<mew-summary-mode-map>\\[mew-summary
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
-;;; SSH/SSL
+;;; SSH/SSL/TLS
 ;;;
 
 (defcustom mew-ssh-keep-connection t
@@ -510,7 +513,7 @@ is kept for further connections. This must be 't' for IMAP and NNTP."
   :type 'boolean)
 
 (defcustom mew-ssl-keep-connection t
-  "*If non-nil, an SSL process for each service (POP, IMAP, NNTP, SMTP)
+  "*If non-nil, an SSL/TLS process for each service (POP, IMAP, NNTP, SMTP)
 is kept for further connections. This must be 't' for IMAP and NNTP."
   :group 'mew-net
   :type 'boolean)
@@ -535,15 +538,16 @@ use a string. (e.g. \"25\")"
 (defcustom mew-smtp-ssh-server nil
   "*The name of SSH server which forwards the SMTP port."
   :group 'mew-smtp
-  :type '(choice string (const nil)))
+  :type '(choice (const :tag "Not use" nil)
+		 (string :tag "Ssh server")))
 
 (defcustom mew-smtp-ssl nil
-  "*If non-nil, SMTP connections are made over SSL."
+  "*If non-nil, SMTP connections are made over SSL/TLS."
   :group 'mew-smtp
   :type 'boolean)
 
 (defcustom mew-smtp-ssl-port "465" ;; no universal consensus
-  "*The port for SMTP over SSL."
+  "*The port for SMTP over SSL/TLS."
   :group 'mew-smtp
   :type 'string)
 
@@ -605,7 +609,8 @@ value of 'mew-mail-domain' is used."
   :type '(choice string (const nil)))
 
 (defcustom mew-mbox-command-arg "-u"
-  "*Arguments for 'mew-mbox-command'."
+  "*Arguments for 'mew-mbox-command'.
+For maildir, set this to '-u -d /path/to/mbox'."
   :group 'mew-pop
   :type '(choice string (const nil)))
 
@@ -648,12 +653,12 @@ use a string. (e.g. \"110\")"
   :type '(choice string (const nil)))
 
 (defcustom mew-pop-ssl nil
-  "*If non-nil, POP connections are made over SSL."
+  "*If non-nil, POP connections are made over SSL/TLS."
   :group 'mew-pop
   :type 'boolean)
 
 (defcustom mew-pop-ssl-port "pop3s"
-  "*The port for POP over SSL."
+  "*The port for POP over SSL/TLS."
   :group 'mew-pop
   :type 'string)
 
@@ -670,19 +675,22 @@ t means SASL according to 'mew-pop-auth-list'."
   :group 'mew-pop
   :type '(choice (const apop) (const pass) (const t)))
 
-(defcustom mew-pop-auth-list '("CRAM-MD5")
+(defcustom mew-pop-auth-list '("CRAM-MD5" "PLAIN")
   "*A list of SASL methods in the preferred order.
 Currently, \"CRAM-MD5\" can be used."
   :group 'mew-pop
-  :type '(repeat (choice (const "CRAM-MD5"))))
+  :type '(repeat (choice (const "CRAM-MD5") (const "PLAIN"))))
 
 (defcustom mew-pop-delete t
-  "*Wether or not delete messages on a POP server after retrieval by
+  "*Whether or not delete messages on a POP server after retrieval by
 POP. If t, delete the messages. If nil, retain the messages. If
 number N, delete the messages N days after the first access.
 Otherwise they are not deleted."
   :group 'mew-pop
-  :type 'boolean)
+  :type '(choice
+	  (const :tag "Delete immediately" t)
+	  (const :tag "Retain the messages" nil)
+	  (integer :tag "Delete N days after")))
 
 (defcustom mew-pop-size (* 54 1024) ;; 4K hdr + 50K bdy
   "*The limit size of messages to be retrieved by POP. The default is
@@ -698,7 +706,7 @@ exceeds 'mew-pop-size'."
   :type 'integer)
 
 (defcustom mew-pop-header-only nil
-  "*Wether or not the body of a message is retrieved by POP.
+  "*Whether or not the body of a message is retrieved by POP.
 If non-nil, only header is retrieved."
   :group 'mew-pop
   :type 'boolean)
@@ -706,7 +714,8 @@ If non-nil, only header is retrieved."
 (defcustom mew-pop-proxy-server nil
   "*The name of PROXY server connecting to POP server."
   :group 'mew-pop
-  :type 'string)
+  :type '(choice (const :tag "Not use" nil)
+		 (string :tag "Pop proxy server")))
 
 (defcustom mew-pop-proxy-port nil
   "*The port of PROXY proxy."
@@ -738,12 +747,12 @@ use a string. (e.g. \"143\")"
   :type '(choice string (const nil)))
 
 (defcustom mew-imap-ssl nil
-  "*If non-nil, IMAP connections are made over SSL."
+  "*If non-nil, IMAP connections are made over SSL/TLS."
   :group 'mew-imap
   :type 'boolean)
 
 (defcustom mew-imap-ssl-port "imaps"
-  "*The port for IMAP over SSL."
+  "*The port for IMAP over SSL/TLS."
   :group 'mew-imap
   :type 'string)
 
@@ -766,7 +775,7 @@ Currently, \"CRAM-MD5\" and \"LOGIN\" can be used."
   :type '(repeat (choice (const "CRAM-MD5") (const "LOGIN"))))
 
 (defcustom mew-imap-delete t
-  "*Wether or not delete messages on an IMAP server after retrieval by
+  "*Whether or not delete messages on an IMAP server after retrieval by
 IMAP. If t, delete the messages. If nil, retain the messages. If
 number N, delete the messages N days after the first access.
 Otherwise they are not deleted."
@@ -781,7 +790,7 @@ IMAP server."
   :type 'integer)
 
 (defcustom mew-imap-header-only nil
-  "*Wether or not the body of a message is retrieved by IMAP.
+  "*Whether or not the body of a message is retrieved by IMAP.
 If non-nil, only header is retrieved."
   :group 'mew-imap
   :type 'boolean)
@@ -845,12 +854,12 @@ use a string. (e.g. \"119\")"
   :type '(choice string (const nil)))
 
 (defcustom mew-nntp-ssl nil
-  "*If non-nil, NNTP connections are made over SSL."
+  "*If non-nil, NNTP connections are made over SSL/TLS."
   :group 'mew-nntp
   :type 'boolean)
 
 (defcustom mew-nntp-ssl-port "nntps"
-  "*The port for NNTP over SSL."
+  "*The port for NNTP over SSL/TLS."
   :group 'mew-nntp
   :type 'string)
 
@@ -858,7 +867,8 @@ use a string. (e.g. \"119\")"
   "*The user name on the NNTP server. If non-nil, authentication is
 used."
   :group 'mew-nntp
-  :type 'string)
+  :type '(choice (const :tag "Not use" nil)
+		 (string :tag "Nntp user")))
 
 (defcustom mew-nntp-newsgroup "-fj.mail.reader.mew"
   "*The name of default Newsgroup."
@@ -873,7 +883,7 @@ NNTP server."
   :type 'integer)
 
 (defcustom mew-nntp-header-only nil
-  "*Wether or not the body of a message is retrieved by NNTP.
+  "*Whether or not the body of a message is retrieved by NNTP.
 If non-nil, only header is retrieved."
   :group 'mew-nntp
   :type 'boolean)
@@ -1217,14 +1227,18 @@ of the From: field is used."
 duplicated messages. If a character, use it as a mark
 instead of the 'D' mark."
   :group 'mew-summary
-  :type 'boolean)
+  :type '(choice (const :tag "Use mew-mark-delete" t)
+		 (const :tag "Not use" nil)
+		 (character :tag "Use another character")))
 
 (defcustom mew-summary-form-mark-review nil
   "*If non-nil, the '*' mark automatically is put onto
 messages destined to me. If a character, use it as a mark
 instead of the '*' mark."
   :group 'mew-summary
-  :type 'boolean)
+  :type '(choice (const :tag "Use mew-mark-review" t)
+		 (const :tag "Not use" nil)
+		 (character :tag "Use another character")))
 
 (defcustom mew-summary-form-size-0k nil
   "*If non-nil, the size of message is displayed as '0k'
@@ -1339,7 +1353,8 @@ See also 'mew-header-max-length'."
   "*A value for the max number of message IDs in References: when reply.
 Non-integer means no limit."
   :group 'mew-reply
-  :type 'integer)
+  :type '(choice (integer :tag "Max count")
+		 (const :tag "No limit" nil)))
 
 (defcustom mew-lisp-max-length 2000
   "*Mew saves an internal lisp structure to a file truncating
@@ -1461,7 +1476,7 @@ message is stored."
   :type 'boolean)
 
 (defcustom mew-ask-folder-after-burst nil
-  "*If *non-nil*, Mew asks to move to the folder where the bursted
+  "*If *non-nil*, Mew asks to move to the folder where the burst
 messages are stored."
   :group 'mew-summary
   :type 'boolean)
@@ -1701,12 +1716,12 @@ learned address are used."
   :type 'boolean)
 
 (defcustom mew-use-unread-mark nil
-  "*If non-nil, the uread mark is used in Summary mode."
+  "*If non-nil, the unread mark is used in Summary mode."
   :group 'mew-summary
   :type 'boolean)
 
 (defcustom mew-delete-unread-mark-by-mark t
-  "*If nil, the uread mark remains when the cursor is moved
+  "*If nil, the unread mark remains when the cursor is moved
 to the current message from the previous message by
 putting any mark on the previous one. If non-nil,
 the unread mark is deleted."
@@ -1819,7 +1834,7 @@ where the cursor jumped to the bottom."
   :type 'boolean)
 
 (defcustom mew-summary-region-include-cursor-line nil
-  "*This value decides wether or not the cursor line is included
+  "*This value decides whether or not the cursor line is included
 to a region."
   :group 'mew-summary
   :type '(choice (const :tag "Include if the cursor is not on the beginning of the line" nil)
@@ -1996,7 +2011,7 @@ according to 'mew-cite-format' and 'mew-cite-fields'."
   :type 'function)
 
 (defcustom mew-cite-prefix-confirmp nil
-  "*If *non-nil*, ciattion prefix (such as 'kazu> ') is
+  "*If *non-nil*, citation prefix (such as 'kazu> ') is
 confirmed to be used."
   :group 'mew-cite
   :type 'boolean)
@@ -2167,7 +2182,7 @@ as the final part."
 (defcustom mew-cs-samba 'shift_jis
   "*A character set before SAMBA encoding."
   :group 'mew-summary
-  :type 'symbol)
+  :type 'coding-system)
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
@@ -2242,7 +2257,8 @@ circular domain completion."
 (defcustom mew-field-delete-common '("From " ">From" "X-Mew")
   "*A field list to be deleted for reediting/resending/forwarding/saving."
   :group 'mew-draft
-  :type '(repeat string))
+  :type '(choice (const nil)
+		 (repeat :tag "Field list" (string :tag "Field"))))
 
 (defvar mew-field-delete nil) ;; backward compatibility
 
@@ -2254,7 +2270,8 @@ circular domain completion."
 	"Lines:" "Status:" "Posted:" "Forwarded:" "Replied:" "X-UIDL:"))
   "*A field list to be deleted when edit again."
   :group 'mew-draft
-  :type '(repeat string))
+  :type '(choice (const nil)
+		 (repeat :tag "Field list" (string :tag "Field"))))
 
 (defcustom mew-field-delete-for-others
   `(,mew-received: "Return-Path:" "Delivery-Date:" "Delivered-To:"
@@ -2262,7 +2279,8 @@ circular domain completion."
     "Lines:" "Status:" "Posted:" "Forwarded:" "Replied:" "X-UIDL:")
   "*A field list to be deleted when send with different To: and Cc:."
   :group 'mew-draft
-  :type '(repeat string))
+  :type '(choice (const nil)
+		 (repeat :tag "Field list" (string :tag "Field"))))
 
 (defcustom mew-field-delete-for-resending
   `(,mew-received: "Return-Path:" "Delivery-Date:" "Delivered-To:"
@@ -2270,30 +2288,33 @@ circular domain completion."
     "Lines:" "Status:" "Posted:" "Forwarded:" "Replied:" "X-UIDL:")
   "*A field list to be deleted when resending."
   :group 'mew-draft
-  :type '(repeat string))
+  :type '(choice (const nil)
+		 (repeat :tag "Field list" (string :tag "Field"))))
 
 (defcustom mew-field-delete-for-forwarding
   '("Lines:" "Status:" "Posted:" "Forwarded:" "Replied:" "X-UIDL:")
   "*A field list to be deleted when forwarding."
   :group 'mew-draft
-  :type '(repeat string))
+  :type '(choice (const nil)
+		 (repeat :tag "Field list" (string :tag "Field"))))
 
 (defcustom mew-field-delete-for-saving ()
   "*A field list to be deleted when saving a message to a file."
   :group 'mew-summary
-  :type '(repeat string))
+  :type '(choice (const nil)
+		 (repeat :tag "Field list" (string :tag "Field"))))
 
 (defcustom mew-field-delete-for-joining
   `(,mew-mv: ,mew-subj: ,mew-message-id: "Encrypted" "Content-")
   "*A field list to be deleted when joining."
   :group 'mew-summary
-  :type '(repeat string))
+  :type '(repeat :tag "Field list" (string :tag "Field")))
 
 (defcustom mew-field-for-printing
   '("Subject:" "From:" "To:" "Cc:" "Date:")
   "*A field list to print"
   :group 'mew-summary
-  :type '(repeat string))
+  :type '(repeat :tag "Field list" (string :tag "Field")))
   
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
@@ -2540,7 +2561,7 @@ The first member is displayed as a default value."
   :type '(choice (const nil) (repeat string)))
 
 (defcustom mew-sort-default-key "date"
-  "*Default sort key when inputing a sort key. 
+  "*Default sort key when inputting a sort key. 
 Its format is key:mode where more is found in 'mew-sort-mode'."
   :group 'mew-summary
   :type 'string)
@@ -2782,10 +2803,7 @@ appropriate for this value."
                  (const pgp-encryption)
                  (const pgp-signature-encryption)
 		 (const pgp-encryption-signature)
-		 (const smime-signature)
-		 (const smime-encryption)
-		 (const smime-signature-encryption)
-		 (const smime-encryption-signature)
+		 (const smime-signature) ;; xxx
                  (other :tag "nil" nil)))
 
 (defcustom mew-protect-privacy-encrypted nil
@@ -3078,7 +3096,7 @@ Level 2: syntax error."
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 1996-2003 Mew developing team.
+;; Copyright (C) 1996-2005 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
