@@ -88,6 +88,7 @@ cdr is new text.")
 (defvar mew-error-invalid-b-encoding " **B ENCODING ERROR** ")
 (defvar mew-error-invalid-q-encoding " **Q ENCODING ERROR** ")
 (defvar mew-error-no-subject         "** no subject **")
+(defvar mew-error-broken-address     "**BROKEN ADDRESS**")
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
@@ -328,9 +329,31 @@ in draft buffer.")
     ("application/vnd.ms-powerpoint" "\\.ppt$"  mew-b64
      mew-prog-mspowerpoint           mew-icon-text)
     ("application/vnd.visio"         "\\.vsd$"  mew-b64
-     mew-prog-visio                  mew-icon-unknown)
+     mew-prog-visio                  mew-icon-text)
+    ("application/vnd.sun.xml.writer"           "\\.sxw$"  mew-b64
+     mew-prog-ooffice                mew-icon-text)
+    ("application/vnd.sun.xml.writer.template"  "\\.stw$"  mew-b64
+     mew-prog-ooffice                mew-icon-text)
+    ("application/vnd.sun.xml.calc"             "\\.sxc$"  mew-b64
+     mew-prog-ooffice                mew-icon-text)
+    ("application/vnd.sun.xml.calc.template"    "\\.stc$"  mew-b64
+     mew-prog-ooffice                mew-icon-text)
+    ("application/vnd.sun.xml.draw"             "\\.sxd$"  mew-b64
+     mew-prog-ooffice                mew-icon-text)
+    ("application/vnd.sun.xml.draw.template"    "\\.std$"  mew-b64
+     mew-prog-ooffice                mew-icon-text)
+    ("application/vnd.sun.xml.impress"          "\\.sxi$"  mew-b64
+     mew-prog-ooffice                mew-icon-text)
+    ("application/vnd.sun.xml.impress.template" "\\.sti$"  mew-b64
+     mew-prog-ooffice                mew-icon-text)
+    ("application/vnd.sun.xml.writer.global"    "\\.sxg$"  mew-b64
+     mew-prog-ooffice                mew-icon-text)
+    ("application/vnd.sun.xml.math"             "\\.sxm$"  mew-b64
+     mew-prog-ooffice                mew-icon-text)
     ("application/ms-tnef"           "\\.dat$" mew-b64
      mew-prog-mstnef                 mew-icon-unknown)
+    ("application/rtf"               "\\.rtf$" mew-b64
+     mew-prog-rtf                    mew-icon-text)
     ("application/pgp-keys"          "\\.pka$"  nil
      mew-prog-pgp-keys               mew-icon-unknown)
     ("application/x-pkcs7-signature" "\\.p7s$"  mew-b64
@@ -355,7 +378,7 @@ in draft buffer.")
     ("text/rfc822-headers" "\\.hdr$" nil
      mew-prog-rfc822-headers     mew-icon-message/rfc822)
     ("text"         "^$"        nil     mew-prog-text      mew-icon-text)
-    ;; Unkown CT: matches here.
+    ;; Unknown CT: matches here.
     (t               "^$"       nil   mew-prog-octet-stream mew-icon-unknown)
     ;; Unknown suffix matches here and return the entry specified 
     ;; by mew-content-type.
@@ -454,18 +477,13 @@ the next version of Mew.")
 ;;;
 
 (defcustom mew-privacy-database
-  `((smime-signature ((,mew-ct-mls ,mew-ct-sms)) "SS")
-    (smime-encryption ((,mew-ct-mle ,"application/x-pkcs7-mime")) "SE")
-    (smime-signature-encryption
-     ((,mew-ct-mls ,mew-ct-sms) (,mew-ct-mle ,"application/x-pkcs7-mime")) "SSSE")
-    (smime-encryption-signature
-     ((,mew-ct-mle ,"application/x-pkcs7-mime") (,mew-ct-mls ,mew-ct-sms)) "SESS")
-    (pgp-signature  ((,mew-ct-mls ,mew-ct-pgs)) "PS")
+  `((pgp-signature  ((,mew-ct-mls ,mew-ct-pgs)) "PS")
     (pgp-encryption ((,mew-ct-mle ,mew-ct-pge)) "PE")
     (pgp-signature-encryption
      ((,mew-ct-mls ,mew-ct-pgs) (,mew-ct-mle ,mew-ct-pge)) "PSPE")
     (pgp-encryption-signature
-     ((,mew-ct-mle ,mew-ct-pge) (,mew-ct-mls ,mew-ct-pgs)) "PEPS"))
+     ((,mew-ct-mle ,mew-ct-pge) (,mew-ct-mls ,mew-ct-pgs)) "PEPS")
+    (smime-signature  ((,mew-ct-mls ,mew-ct-sms)) "SS"))
   "*Alist of key, a list of privacy Content-Type, and its mark."
   :group 'mew-privacy
   :type 'sexp)
@@ -1040,7 +1058,7 @@ Currently, the following keys are supported:
 \"cc\", \"fcc\", \"dcc\", \"reply-to\", \"organization\", \"header-alist\", 
 \"proto\", 
 \"smtp-server\", \"smtp-port\", \"smtp-ssh-server\", \"smtp-ssl\", \"smtp-ssl-port\", 
-\"smtp-user\", \"smtp-auth\", \"smtp-auth-list\", 
+\"smtp-user\", \"smtp-auth-list\", 
 \"smtp-msgid-user\", \"smtp-msgid-domain\", \"smtp-helo-domain\", \"smtp-mail-from\", 
 \"pop-server\", \"pop-port\", \"pop-ssh-server\", \"pop-ssl\", \"pop-ssl-port\", 
 \"pop-user\", \"pop-auth\", \"pop-auth-list\",
@@ -1089,7 +1107,7 @@ An example is as follows:
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 2000-2003 Mew developing team.
+;; Copyright (C) 2000-2005 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
