@@ -221,6 +221,8 @@ popup menu can be implemented."
     (add-submenu nil mew-summary-mode-menu-spec)
     (easy-menu-add mew-summary-mode-menu-spec)))
 
+(defun mew-message-setup-decoration () nil) ;; xxx
+
 (defun mew-draft-setup-decoration ()
   (mew-draft-toolbar-update)
   (when mew-icon-p
@@ -484,7 +486,7 @@ popup menu can be implemented."
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
-;;; SSL/SSH notification
+;;; SSL/SSH/TLS notification
 ;;;
 
 (defvar mew-secure-format
@@ -499,7 +501,7 @@ popup menu can be implemented."
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 1997-2003 Mew developing team.
+;; Copyright (C) 1997-2005 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
