@@ -2,7 +2,7 @@
 
 ;; Author:  Kazu Yamamoto <Kazu@Mew.org>
 ;; Created: Mar 23, 1994
-;; Revised: Oct 18, 2004
+;; Revised: Feb  9, 2005
 
 ;;; Commentary:
 
@@ -19,7 +19,7 @@
 ;;; Mew version
 ;;;
 
-(defconst mew-version-number "4.1"
+(defconst mew-version-number "4.2"
   "Version number for this version of Mew.")
 (defconst mew-version (format "Mew version %s" mew-version-number)
   "Version string for this version of Mew.")
@@ -238,13 +238,15 @@ If executed with '3', information about IMAP folders is updated."
     (mew-addrbook-setup)
     (mew-scan-setup)
     (mew-pgp-setup)
+    (mew-smime-setup)
     (mew-ssh-setup)
     (mew-ssl-setup)
     (mew-net-setup)
     (mew-thread-setup)
     (mew-theme-setup)
     (mew-biff-setup)
-    (mew-ct-setup)))
+    (mew-ct-setup)
+    (mew-nmz-clean-up)))
   (unless (or (eq arg 2) (eq arg 3))
     (message "Updating status...done")))
 
@@ -350,7 +352,7 @@ If executed with '3', information about IMAP folders is updated."
       ret)))
 
 (defun mew-window-configure (action)
-  "Configure windows accroding to ACTION.
+  "Configure windows according to ACTION.
 ACTION should be symbol or a list of two numbers.
 Predefined symbol is 'summary, 'message, and 'draft.
 They are used as a key of 'mew-window-configuration to get
@@ -386,7 +388,7 @@ the lower window is not zero, switch to the buffer."
       (save-excursion
 	(set-buffer (get-buffer-create msgbuf))
 	;; "truncate?" is asked in Message mode.
-	;; so set the same toolbar as Sumamry mode
+	;; so set the same toolbar as Summary mode
 	(mew-summary-toolbar-update)
 	(mew-message-mode)))
     ;;
@@ -580,7 +582,7 @@ It is typically called by kill-emacs-hook."
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
-;;; Teer down
+;;; Tear down
 ;;;
 
 (defun mew-bury-buffer (&optional buf)
@@ -655,6 +657,7 @@ Mew remain, so you can resume with buffer operations."
     (mew-highlight-timer-clean-up)
     (mew-net-clean-up)
     (mew-biff-clean-up)
+    (mew-nmz-clean-up)
     ;;
     (mew-window-pop)
     (mew-window-clean-up)
@@ -712,10 +715,11 @@ Mew remain, so you can resume with buffer operations."
 (require 'mew-imap2)
 (require 'mew-config)
 (require 'mew-auth)
+(require 'mew-nmz)
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 1994-2003 Mew developing team.
+;; Copyright (C) 1994-2005 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
